setwd("D:/OneDrive/1 INVESTIGACION/HECHOS PUBLICADOS O EN ESPERA/Amir Pakpour - submitted IJERPH/RyR IJERPH")

#load packages
require(qgraph)
require(rio)
require(dplyr)
library(bootnet)
require(psych)
library(mgm)
library(networktools)
library(EGAnet)

library(NetworkComparisonTest)
library(EstimateGroupNetwork)
library(dplyr)
library(tidyverse)
library(reshape)
library(parallel)

#import data
data_imp<-import("Data FearCovid19 processed.sav"); data_imp
#rename variables
data<-data_imp[,c("FC1","FC2","FC3","FC4","FC5","FC6","FC7")]
data<-dplyr::rename(data,"Afraid" = "FC1", "Umconf" = "FC2","ClammyHands" = "FC3",
             "AfraidDie" = "FC4","AnxNews" =  "FC5", "Insomnia" = "FC6", "HeartRaces" = "FC7")
headTail(data)
#Change value 9 to 3 (it's a 1 to 5 scale)
data[data == 9] <- 3

#get descriptive statistics for dataset
des <- describe(data); des
means <- colMeans(data, na.rm=T)
lattice::histogram(means)
sds <- as.vector(sapply(data, sd, na.rm=T))
lattice::histogram(sds)


#set seed for reproducibility
set.seed(1912)

## Identifying any potentially redundant nodes in the cross-sectional network - None suggested

#correlations
datacor <- cor_auto(data)
datacor #visualize correlation matrix

#write.csv(datacor, "cormatrixitems.csv")


diag(datacor)=NA
cors <- lavaan::lav_matrix_vech(datacor)
psych::describe(cors) #extract lower triangle of correlations and describe it
lattice::histogram(cors) #histogram

mean(cors,na.rm=T)+3*sd(cors,na.rm=T)
mean(cors,na.rm=T)-3*sd(cors,na.rm=T)

mean(cors,na.rm=T)+2*sd(cors,na.rm=T)
mean(cors,na.rm=T)-2*sd(cors,na.rm=T)

mean(cors,na.rm=T)+sd(cors,na.rm=T)
mean(cors,na.rm=T)-sd(cors,na.rm=T)

gold <- goldbricker(data, p = 0.05, method = "meng1992", threshold = 0.25,
                    corMin = 0.263, progressbar = TRUE); gold #0.263 as 1SD above mean of items with potential conceptual overlap

#No pairs flagged

## create composite nodes 
#data <- net_reduce(data=data, badpairs=gold, method="PCA")
#net_reduce(data=data, badpairs=gold, method="best_goldbricker")
#write.csv(data, "reduceditems.csv")
#data <- read.csv("reduceditems edited.csv",header=TRUE,sep=";",dec=",")

## No poorly informative items either

##Checking whether there are any poorly informative items
sds <- as.vector(sapply(data, sd, na.rm=T))
lattice::histogram(sds)
psych::describe(sds) #average informativeness is 1.09
min(sds) #the less informative item = 0.85
mean(sds)-2.5*sd(sds) #informativeness for the least informative item is comprised in the -+ 2.5 SD 
#Hence, I recommend that no item should be excluded




#analysis following epskamp & fried 2018
results <- estimateNetwork(data, default = "EBICglasso",corMethod = "cor_auto",tuning = 0.5,principalDirection = TRUE)
#alternative estimation, gets sometimes better results
results2 <- estimateNetwork(data, default = "ggmModSelect",corMethod = "cor_auto",tuning = 0.5,principalDirection = TRUE)

#plot it
plot(results)

#power analysis
simRes1 <- netSimulator(results$graph,
                        dataGenerator = ggmGenerator(ordinal = TRUE, nLevels = 5),
                        default = "EBICglasso",
                        nCases = c(5000,10000,24429,30000,50000),
                        tuning = 0.5,
                        nReps = 100,
                        nCores = 5
)

#simRes1
plot(simRes1) #really low specificity
plot(simRes1,yvar = c("ExpectedInfluence","closeness","betweenness","strength")) #all good, strength>closeness>betweenness

simRes2 <- netSimulator(results2$graph,
                        dataGenerator = ggmGenerator(ordinal = TRUE, nLevels = 5),
                        default = "ggmModSelect",
                        nCases = c(5000,10000,24429,30000,50000),
                        tuning = 0.5,
                        nReps = 100,
                        nCores = 5
)

#simRes2
plot(simRes2) #now really high values in correlations, sensitivity and specificity
plot(simRes2,yvar = c("ExpectedInfluence","closeness","betweenness","strength")) #all still good


simRes1Replication <- replicationSimulator(results$graph,
                                           dataGenerator = ggmGenerator(ordinal = TRUE, nLevels = 5),
                                           default = "EBICglasso",
                                           nCases = c(5000,10000,24429,30000,50000),
                                           tuning = 0.5,
                                           nReps = 500,
                                           nCores = 5
)

plot(simRes1Replication) #really low replicatedZeroes
plot(simRes1Replication,yvar = c("closeness","betweenness","strength")) #all good again, strength>closeness>betweenness

simRes2Replication <- replicationSimulator(results2$graph,
                                           dataGenerator = ggmGenerator(ordinal = TRUE, nLevels = 5),
                                           default = "ggmModSelect",
                                           nCases = c(5000,10000,24429,30000,50000),
                                           tuning = 0.5,
                                           nReps = 500,
                                           nCores = 5
)

plot(simRes2Replication) #now all good
plot(simRes2Replication,yvar = c("closeness","betweenness","strength")) #all still good, betweenness>closeness>strength



plot(simRes1) #really low specificity
plot(simRes1,yvar = c("ExpectedInfluence","closeness","betweenness","strength")) #all good, strength>closeness>betweenness

plot(simRes2) #now really high values in correlations, sensitivity and specificity
plot(simRes2,yvar = c("ExpectedInfluence","closeness","betweenness","strength")) #all still good


plot(simRes1Replication) #really low replicatedZeroes
plot(simRes1Replication,yvar = c("closeness","betweenness","strength")) #all good again, strength>closeness>betweenness

plot(simRes2Replication) #now all good
plot(simRes2Replication,yvar = c("closeness","betweenness","strength")) #all still good, betweenness>closeness>strength

#WE CONCLUDE TO USE THE GGMMODSELECT ("results2") ESTIMATION METHOD SINCE BETTER POWER AND REPLICABILITY OUTPUTS

#node predictability
type=rep('g', 7) #g=gaussian, 17 = number of nodes in the network
fit1<-mgm(data,
          type=type, 
          level=rep(1,7)
          )

pred1<- predict(fit1, data)
pred1$error$R2
mean(pred1$error$R2)
sd(pred1$error$R2)

#let us see the network
graph1 <- plot(results2,pie = pred1$error$R2)


centrality(results2)
centralityPlot(results2, include = "all", orderBy = "Strength")

#bootstrapping for stability (i.e. replicability) of network
parallel::detectCores(all.tests = FALSE, logical = TRUE)

boot1 <- bootnet(results2, nCores = 14, #introduce as many cores as detectCores() detects - 2
                 nBoots = 1000, type ='nonparametric',
                 statistics=c("edge","strength","expectedInfluence","closeness","betweenness"),
                 computeCentrality=TRUE,weighted=TRUE,signed=TRUE,memorysaver=TRUE)
plot(boot1, statistics = "all",order = "sample")
plot(boot1,"edge", plot = "interval", order = "sample") #confidence intervals instead of shades
plot(boot1, statistics = "all",order = "sample",plot="line") #raw data lines instead of CIs
plot(boot1,c("strength","expectedInfluence","betweenness","closeness"), plot = "area", order = "sample") #interpret CIs with care due to being unstable
fplot(boot1,c("strength","expectedInfluence","betweenness","closeness"), plot = "line", order = "sample") 


plot(boot1, "edge", plot = "difference",
     onlyNonZero = TRUE, differenceShowValue=FALSE, 
     differenceEdgeColor=TRUE, order = "sample") #significant differences between each edge (black = sig; grey = ns)
plot(boot1, c("strength","expectedInfluence","closeness","betweenness"), plot = "difference") 

#differenceTest(boot1,  "Umconf", "Insomnia", "expectedInfluence") #check specific contrasts

boot2 <- bootnet(results2, nCores = 14,nBoots = 1000, type ='case',statistics = c("edge","strength","expectedInfluence", "betweenness","closeness"))
plot(boot2,statistics = "edge")
plot(boot2,statistics = c("strength","expectedInfluence","betweenness","closeness"))

# Compute CS-coefficients: Cautious interpretation rules = above .25 minimum, above .50 ideal
corStability(boot2,cor=0.7,statistics="edge",verbose=TRUE) #changing the "cor" argument does not change the output

boot3 <- bootnet(results2, nCores = 14,nBoots = 1000, type ='node',statistics = c("edge","strength","expectedInfluence", "betweenness","closeness"),computeCentrality = TRUE)
plot(boot3,statistics = "edge")
plot(boot3,statistics = c("strength","closeness"))


#Conclusion: The network seems very stable and sample has high power





#EGA

datacor <- cor_auto(data)

set.seed(1234)

for(i in 3:20) {
  sgc <- EGA(datacor,model = "glasso",n=191695,steps=i,plot.EGA=FALSE)
  print(sgc$dim.variables$dimension)
  print(table(sgc$dim.variables$dimension))
}

egacovid3 <- EGA(datacor,model="glasso",n=191695,steps=3,plot.EGA=FALSE); egacovid3
egacovid4 <- EGA(datacor,model="glasso",n=191695,steps=4,plot.EGA=FALSE); egacovid4
egacovid5 <- EGA(datacor,model="glasso",n=191695,steps=5,plot.EGA=FALSE); egacovid5
egacovid6 <- EGA(datacor,model="glasso",n=191695,steps=6,plot.EGA=FALSE); egacovid6
egacovid7 <- EGA(datacor,model="glasso",n=191695,steps=7,plot.EGA=FALSE); egacovid7
egacovid8 <- EGA(datacor,model="glasso",n=191695,steps=8,plot.EGA=FALSE); egacovid8


# all steps converge in 1 cluster






#EGA only uses walktrap algorithm when others can be useful, i.e. spinglass
# following https://www.nature.com/articles/srep30750, Waltrap, Spinglass and Multilevel are able to estimate correctly networks with < 1000 nodes

# DETAILED EXPLANATIONS OF EACH ALGORITHM: https://stackoverflow.com/questions/9471906/what-are-the-differences-between-community-detection-algorithms-in-igraph

#Here is the exact same function for EGA but changing "walktrap" for "spinglass", "steps" for "spins" and 4 default steps to 25 default spins (following defaults of igraph). Original function at https://github.com/hfgolino/EGAnet/blob/master/R/EGA.R
EGAspinglass <- function (data, model = c("glasso", "TMFG"), plot.EGA = TRUE, n = NULL,
                          spins = 25, nvar = 4, nfact = 1, load = 0.70, ...) {
  
  #-------------------------------------------------------------------------
  ## CHECKING DATA STRUCTURE
  #-------------------------------------------------------------------------
  if(nrow(data)!=ncol(data)){
    data <- as.data.frame(data)
    n <- nrow(data)
  }
  
  if (nrow(data) == ncol(data)){
    cor.data <- data
    if (missing(model)) {
      model = "glasso"
    }
    else {
      model = match.arg(model)
    }
    if (model == "glasso") {
      gamma.values <- c(0.50, 0.25, 0)
      gvals <- iterators::iter(gamma.values)
      repeat {
        estimated.network <- EBICglasso.qgraph(data = cor.data,
                                               n = n,
                                               lambda.min.ratio = 0.1,
                                               returnAllResults = FALSE,
                                               gamma = iterators::nextElem(gvals), ...)
        if (any(NetworkToolbox::strength(estimated.network)>0)) {
          break
        }
      }
    }
    else if (model == "TMFG") {
      estimated.network <- NetworkToolbox::TMFG(cor.data, ...)$A
    }
    graph <- NetworkToolbox::convert2igraph(abs(estimated.network))
    wc <- igraph::spinglass.community(graph, spins = spins)
    names(wc$membership) <- colnames(data)
    n.dim <- max(wc$membership)
    wc <- wc$membership
  } else{
    
    
    #-------------------------------------------------------------------------
    ## DATA GENERATION
    #-------------------------------------------------------------------------
    
    nvar <- nvar
    nfac <- nfact
    n <- nrow(data)
    load <- load
    corf <- 0
    J       = nvar*nfac
    sdcross = 0
    
    ## GENERATE SAMPLE DATA MATRIX
    check.eig <- TRUE
    check.com <- TRUE
    
    while(check.eig == TRUE|check.com == TRUE){
      
      SATF = matrix(0, J, nfac)
      
      for(j in 1:nfac){
        SATF[(j*nvar-nvar+1):(j*nvar),j]<-runif(nvar, load-.10, load+.10)
        if(nfac>1){
          CROSS.L = apply(as.matrix(SATF[(j*nvar-nvar+1+2):(j*nvar),-c(j)]), ## Generate cross-loadings
                          2,
                          function(x) rnorm((nvar-2), 0, sdcross))
          SATF[(j*nvar-nvar+1+2):(j*nvar),-c(j)] = CROSS.L
        }
      }
      SATF # Population factor loading matrix with cross-loadings and marker items
      
      FCOR      = matrix(corf, nfac, nfac); diag(FCOR)<-1 ## Factor correlation matrix
      R         = SATF%*%FCOR%*%t(SATF)                          ## Rr
      check.com = any(diag(R) > .90)                                  ## Check communalities values
      diag(R)   = 1                                                                    ## Insert ones in the diagonal of Rr
      R                                                                                       ## Rp
      check.eig = any(eigen(R)$values <= 0)                      ## Check eigenvalues
    }
    
    U = chol(R)                                                                       ## Cholesky decomposition of Rp
    Z = mvtnorm::rmvnorm(n, sigma = diag(J))                                  ## Obtain sample matrix of continuous variables
    X = Z%*%U
    X <-as.data.frame(X)
    colnames(X) <- paste0("V", 1:ncol(X))
    
    data.sim <- data.frame(X, data)
    
    #-------------------------------------------------------------------------
    ## EGA WITH SIMULATED DATA + ORIGINAL DATA
    #-------------------------------------------------------------------------
    
    if (missing(model)) {
      model = "glasso"
    }
    else {
      model = match.arg(model)
    }
    
    cor.data.sim <- qgraph::cor_auto(data.sim)
    
    if (model == "glasso") {
      gamma.values <- c(0.50, 0.25, 0)
      gvals <- iterators::iter(gamma.values)
      repeat {
        estimated.network.sim <- EBICglasso.qgraph(data = cor.data.sim,
                                                   n = n,
                                                   lambda.min.ratio = 0.1,
                                                   returnAllResults = FALSE,
                                                   gamma = iterators::nextElem(gvals), ...);
        if (any(NetworkToolbox::strength(estimated.network.sim)>0)) {
          break
        }
      }
    }
    else if (model == "TMFG") {
      estimated.network.sim <- NetworkToolbox::TMFG(cor.data.sim, ...)$A
    }
    graph.sim <- NetworkToolbox::convert2igraph(abs(estimated.network.sim))
    wc.sim <- igraph::spinglass.community(graph.sim, spins = spins)
    names(wc.sim$membership) <- colnames(data.sim)
    n.dim.sim <- max(wc.sim$membership)
    if(n.dim.sim <= (nfact+1)){
      n.dim <- n.dim.sim
      cor.data <- cor.data.sim[-c(1:(nvar*nfact)),-c(1:(nvar*nfact))]
      estimated.network <- estimated.network.sim[-c(1:(nvar*nfact)),-c(1:(nvar*nfact))]
      wc <- wc.sim$membership[-c(1:(nvar*nfact))]
    }
    #-------------------------------------------------------------------------
    ## TRADITIONAL EGA (IF NUMBER OF FACTORS > 2)
    #-------------------------------------------------------------------------
    
    else{
      
      cor.data <- cor.data.sim[-c(1:nvar),-c(1:nvar)]
      
      if (missing(model)) {
        model = "glasso"
      }
      else {
        model = match.arg(model)
      }
      if (model == "glasso") {
        gamma.values <- c(0.50, 0.25, 0)
        gvals <- iterators::iter(gamma.values)
        repeat {
          estimated.network <- EBICglasso.qgraph(data = cor.data,
                                                 n = n,
                                                 lambda.min.ratio = 0.1,
                                                 returnAllResults = FALSE,
                                                 gamma = iterators::nextElem(gvals), ...)
          if (any(NetworkToolbox::strength(estimated.network)>0)) {
            break
          }
        }
      }
      else if (model == "TMFG") {
        estimated.network <- NetworkToolbox::TMFG(cor.data, ...)$A
      }
      graph <- NetworkToolbox::convert2igraph(abs(estimated.network))
      wc <- igraph::spinglass.community(graph, spins = spins)
      names(wc$membership) <- colnames(data)
      n.dim <- max(wc$membership)
      wc <- wc$membership
    }
  }
  a <- list()
  # Returning only communities that have at least two items:
  if(length(unique(wc))>1){
    indices <- seq_along(wc)
    indices2 <- indices[wc %in% wc[duplicated(wc)]]
    wc[indices[-indices2]] <- NA
    a$n.dim <- length(unique(na.omit(wc)))
  }else{
    a$n.dim <- length(unique(wc))
  }
  a$correlation <- cor.data
  a$network <- estimated.network
  a$wc <- wc
  dim.variables <- data.frame(items = colnames(data), dimension = a$wc)
  dim.variables <- dim.variables[order(dim.variables[, 2]),                                ]
  a$dim.variables <- dim.variables
  if (plot.EGA == TRUE) {
    if(a$n.dim <= 2){
      plot.ega <- qgraph::qgraph(a$network, layout = "spring",
                                 vsize = 6, groups = as.factor(a$wc), label.prop = 1, legend = FALSE)
    }else{
      plot.ega <- qgraph::qgraph(a$network, layout = "spring",
                                 vsize = 6, groups = as.factor(a$wc), label.prop = 1, legend = TRUE)
    }
  }
  
  a$EGA.type <- ifelse(a$n.dim <= 2, "Unidimensional EGA", "Traditional EGA")
  class(a) <- "EGA"
  return(a)
}
#----


egacovidsp25 <- EGAspinglass(datacor,model="glasso",n=24429,spins=25,plot=FALSE); egacovidsp25
egacovidsp50 <- EGAspinglass(datacor,model="glasso",n=24429,spins=50,plot=FALSE); egacovidsp50
egacovidsp75 <- EGAspinglass(datacor,model="glasso",n=24429,spins=75,plot=FALSE); egacovidsp75
egacovidsp100 <- EGAspinglass(datacor,model="glasso",n=24429,spins=100,plot=FALSE); egacovidsp100
egacovidsp150 <- EGAspinglass(datacor,model="glasso",n=24429,spins=150,plot=FALSE); egacovidsp150
egacovidsp200 <- EGAspinglass(datacor,model="glasso",n=24429,spins=200,plot=FALSE); egacovidsp200
egacovidsp250 <- EGAspinglass(datacor,model="glasso",n=24429,spins=250,plot=FALSE); egacovidsp250
egacovidsp300 <- EGAspinglass(datacor,model="glasso",n=24429,spins=300,plot=FALSE); egacovidsp300
egacovidsp500 <- EGAspinglass(datacor,model="glasso",n=24429,spins=500,plot=FALSE); egacovidsp500

egacovidspdefault <- EGAspinglass(datacor,model="glasso",n=24429,plot=FALSE)

#for(i in 25:200) {
#  sgc <- EGAspinglass(datacor,model="glasso",n=20910,spins=i,plot=FALSE)
#  print(sgc$dim.variables$dimension)
#  print(table(sgc$dim.variables$dimension))
#}

# all propose 2 groups


#same procedure but for multilevel (louvain) algorithm: Replace "spinglass" for "multilevel", and remove all "spin" arguments

EGAmultilevel <- function (data, model = c("glasso", "TMFG"), plot.EGA = TRUE, n = NULL,
                           nvar = 4, nfact = 1, load = 0.70, ...) {
  
  #-------------------------------------------------------------------------
  ## CHECKING DATA STRUCTURE
  #-------------------------------------------------------------------------
  if(nrow(data)!=ncol(data)){
    data <- as.data.frame(data)
    n <- nrow(data)
  }
  
  if (nrow(data) == ncol(data)){
    cor.data <- data
    if (missing(model)) {
      model = "glasso"
    }
    else {
      model = match.arg(model)
    }
    if (model == "glasso") {
      gamma.values <- c(0.50, 0.25, 0)
      gvals <- iterators::iter(gamma.values)
      repeat {
        estimated.network <- EBICglasso.qgraph(data = cor.data,
                                               n = n,
                                               lambda.min.ratio = 0.1,
                                               returnAllResults = FALSE,
                                               gamma = iterators::nextElem(gvals), ...)
        if (any(NetworkToolbox::strength(estimated.network)>0)) {
          break
        }
      }
    }
    else if (model == "TMFG") {
      estimated.network <- NetworkToolbox::TMFG(cor.data, ...)$A
    }
    graph <- NetworkToolbox::convert2igraph(abs(estimated.network))
    wc <- igraph::multilevel.community(graph)
    names(wc$membership) <- colnames(data)
    n.dim <- max(wc$membership)
    wc <- wc$membership
  } else{
    
    
    #-------------------------------------------------------------------------
    ## DATA GENERATION
    #-------------------------------------------------------------------------
    
    nvar <- nvar
    nfac <- nfact
    n <- nrow(data)
    load <- load
    corf <- 0
    J       = nvar*nfac
    sdcross = 0
    
    ## GENERATE SAMPLE DATA MATRIX
    check.eig <- TRUE
    check.com <- TRUE
    
    while(check.eig == TRUE|check.com == TRUE){
      
      SATF = matrix(0, J, nfac)
      
      for(j in 1:nfac){
        SATF[(j*nvar-nvar+1):(j*nvar),j]<-runif(nvar, load-.10, load+.10)
        if(nfac>1){
          CROSS.L = apply(as.matrix(SATF[(j*nvar-nvar+1+2):(j*nvar),-c(j)]), ## Generate cross-loadings
                          2,
                          function(x) rnorm((nvar-2), 0, sdcross))
          SATF[(j*nvar-nvar+1+2):(j*nvar),-c(j)] = CROSS.L
        }
      }
      SATF # Population factor loading matrix with cross-loadings and marker items
      
      FCOR      = matrix(corf, nfac, nfac); diag(FCOR)<-1 ## Factor correlation matrix
      R         = SATF%*%FCOR%*%t(SATF)                          ## Rr
      check.com = any(diag(R) > .90)                                  ## Check communalities values
      diag(R)   = 1                                                                    ## Insert ones in the diagonal of Rr
      R                                                                                       ## Rp
      check.eig = any(eigen(R)$values <= 0)                      ## Check eigenvalues
    }
    
    U = chol(R)                                                                       ## Cholesky decomposition of Rp
    Z = mvtnorm::rmvnorm(n, sigma = diag(J))                                  ## Obtain sample matrix of continuous variables
    X = Z%*%U
    X <-as.data.frame(X)
    colnames(X) <- paste0("V", 1:ncol(X))
    
    data.sim <- data.frame(X, data)
    
    #-------------------------------------------------------------------------
    ## EGA WITH SIMULATED DATA + ORIGINAL DATA
    #-------------------------------------------------------------------------
    
    if (missing(model)) {
      model = "glasso"
    }
    else {
      model = match.arg(model)
    }
    
    cor.data.sim <- qgraph::cor_auto(data.sim)
    
    if (model == "glasso") {
      gamma.values <- c(0.50, 0.25, 0)
      gvals <- iterators::iter(gamma.values)
      repeat {
        estimated.network.sim <- EBICglasso.qgraph(data = cor.data.sim,
                                                   n = n,
                                                   lambda.min.ratio = 0.1,
                                                   returnAllResults = FALSE,
                                                   gamma = iterators::nextElem(gvals), ...);
        if (any(NetworkToolbox::strength(estimated.network.sim)>0)) {
          break
        }
      }
    }
    else if (model == "TMFG") {
      estimated.network.sim <- NetworkToolbox::TMFG(cor.data.sim, ...)$A
    }
    graph.sim <- NetworkToolbox::convert2igraph(abs(estimated.network.sim))
    wc.sim <- igraph::multilevel.community(graph.sim)
    names(wc.sim$membership) <- colnames(data.sim)
    n.dim.sim <- max(wc.sim$membership)
    if(n.dim.sim <= (nfact+1)){
      n.dim <- n.dim.sim
      cor.data <- cor.data.sim[-c(1:(nvar*nfact)),-c(1:(nvar*nfact))]
      estimated.network <- estimated.network.sim[-c(1:(nvar*nfact)),-c(1:(nvar*nfact))]
      wc <- wc.sim$membership[-c(1:(nvar*nfact))]
    }
    #-------------------------------------------------------------------------
    ## TRADITIONAL EGA (IF NUMBER OF FACTORS > 2)
    #-------------------------------------------------------------------------
    
    else{
      
      cor.data <- cor.data.sim[-c(1:nvar),-c(1:nvar)]
      
      if (missing(model)) {
        model = "glasso"
      }
      else {
        model = match.arg(model)
      }
      if (model == "glasso") {
        gamma.values <- c(0.50, 0.25, 0)
        gvals <- iterators::iter(gamma.values)
        repeat {
          estimated.network <- EBICglasso.qgraph(data = cor.data,
                                                 n = n,
                                                 lambda.min.ratio = 0.1,
                                                 returnAllResults = FALSE,
                                                 gamma = iterators::nextElem(gvals), ...)
          if (any(NetworkToolbox::strength(estimated.network)>0)) {
            break
          }
        }
      }
      else if (model == "TMFG") {
        estimated.network <- NetworkToolbox::TMFG(cor.data, ...)$A
      }
      graph <- NetworkToolbox::convert2igraph(abs(estimated.network))
      wc <- igraph::multilevel.community(graph)
      names(wc$membership) <- colnames(data)
      n.dim <- max(wc$membership)
      wc <- wc$membership
    }
  }
  a <- list()
  # Returning only communities that have at least two items:
  if(length(unique(wc))>1){
    indices <- seq_along(wc)
    indices2 <- indices[wc %in% wc[duplicated(wc)]]
    wc[indices[-indices2]] <- NA
    a$n.dim <- length(unique(na.omit(wc)))
  }else{
    a$n.dim <- length(unique(wc))
  }
  a$correlation <- cor.data
  a$network <- estimated.network
  a$wc <- wc
  dim.variables <- data.frame(items = colnames(data), dimension = a$wc)
  dim.variables <- dim.variables[order(dim.variables[, 2]),                                ]
  a$dim.variables <- dim.variables
  if (plot.EGA == TRUE) {
    if(a$n.dim <= 2){
      plot.ega <- qgraph::qgraph(a$network, layout = "spring",
                                 vsize = 6, groups = as.factor(a$wc), label.prop = 1, legend = FALSE)
    }else{
      plot.ega <- qgraph::qgraph(a$network, layout = "spring",
                                 vsize = 6, groups = as.factor(a$wc), label.prop = 1, legend = TRUE)
    }
  }
  
  a$EGA.type <- ifelse(a$n.dim <= 2, "Unidimensional EGA", "Traditional EGA")
  class(a) <- "EGA"
  return(a)
}
#----

egacovidmulti <- EGAmultilevel(datacor,model="glasso",n=24429,plot=FALSE); egacovidmulti

#multilevel: 2 groups

#NOT NEEDED SINCE ALL ALGORITHMS PROPOSE THE SAME STRUCTURE
#fit of EGA
# doesnt matter spins and steps as long as they offer same or different number of groups
rbind(entropyFit(data=data,structure=egacovid5$wc), #1 group
      entropyFit(data=data,structure=egacovidsp50$wc)) #2 groups

rbind(vn.entropy(data=data,structure=egacovid3$wc), #1 group
      vn.entropy(data=data,structure=egacovidsp250$wc)) #2 groups

#for tefi() we use as input the absolute values of correlation matrix since raw matrix produces NAs (resolved by Golino)
rbind(tefi(data=abs(data),structure=egacovid3$wc), #1 group
      tefi(data=abs(data),structure=egacovidsp250$wc)) #2 groups


CFA(egacovid5,data,estimator="WLSMV",plot.CFA=TRUE,layout="spring")
CFA(egacovidsp100,data,estimator="WLSMV",plot.CFA=TRUE,layout="spring")

net.loads(egacovid5)$std
net.loads(egacovidsp100)$std


## BOOTSTRAP EGA

bootegacovid <- bootEGA(data=data,n=500,model="glasso",type="resampling",algorithm="walktrap",typicalStructure=TRUE,plot.typicalStructure=TRUE,ncores=12,iter=1000)
bootegacovidlouvain <- bootEGA(data=data,n=500,model="glasso",type="resampling",algorithm="louvain",typicalStructure=TRUE,plot.typicalStructure=TRUE,ncores=12,iter=1000)

bootegacovidTMFG <- bootEGA(data=data,n=500,model="TMFG",type="resampling",algorithm="walktrap",typicalStructure=TRUE,plot.typicalStructure=TRUE,ncores=12,iter=1000)
bootegacovidTMFGlouvain <- bootEGA(data=data,n=500,model="TMFG",type="resampling",algorithm="louvain",typicalStructure=TRUE,plot.typicalStructure=TRUE,ncores=12,iter=1000)

bootegacovid$summary.table
bootegacovid$frequency

bootegacovidlouvain$summary.table
bootegacovidlouvain$frequency

bootegacovidTMFG$summary.table
bootegacovidTMFG$frequency

bootegacovidTMFGlouvain$summary.table
bootegacovidTMFGlouvain$frequency

#graphs
plot(bootegacovid)
bootegacovid$typicalGraph
plot(bootegacovidlouvain)
bootegacovidlouvain$typicalGraph
plot(bootegacovidTMFG)
bootegacovidTMFG$typicalGraph
plot(bootegacovidTMFGlouvain)
bootegacovidTMFGlouvain$typicalGraph


#extra indices for bootstrap
#itemStability(bootegacovid,egacovid3$wc,item.freq=0.10,plot.item.rep=TRUE)


dimensionStability(bootegacovid,egacovid3$wc,item.stability=TRUE)
dimensionStability(bootegacovid,egacovid3$wc,item.stability=FALSE) 

dimensionStability(bootegacovidlouvain,egacovid3$wc,item.stability=TRUE)
dimensionStability(bootegacovidlouvain,egacovid3$wc,item.stability=FALSE)

dimensionStability(bootegacovidTMFG,egacovid3$wc,item.stability=TRUE)
dimensionStability(bootegacovidTMFG,egacovid3$wc,item.stability=FALSE)

dimensionStability(bootegacovidTMFGlouvain,egacovid3$wc,item.stability=TRUE)
dimensionStability(bootegacovidTMFGlouvain,egacovid3$wc,item.stability=FALSE)

#the 1-groups solutions is the most stable
#the 2-group solution is supported by spinglass and multilevel, but not on bootstrap

#the spinglass algorithm detects 6 communities -> visualize the network
gr1 <- rep("Fear of COVID-19",7)
gr2 <- list("Psychosocial" = c(1,2,4,5), "Physical" = c(3,6,7))
gr2 <- c("Psychosocial","Psychosocial","Physical","Psychosocial","Psychosocial","Physical","Physical")

par(mfrow=c(1,2))
graph1 <- plot(results2, 
               pie = pred1$error$R2, 
               groups=gr1,
               layout="spring", 
               legend.cex=.40, # scalar on legend size
               vsize=15, 
               #legend.mode = 'style2',
               border.width=2, border.color='#555555',
               minimum = 0.05,minimum = 0.05,
               color="#fee090",
               #,"#e0f3f8"),
               details=TRUE,
               legend=TRUE,
               label.cex=0.9,label.scale.equal=TRUE,label.scale=FALSE
               #labels=1:7,
               #nodeNames=colnames(data)
               )
#color=c("#d73027", "#fc8d59", "#fee090", "#e0f3f8", "#91bfdb", "#d8f781"))

graph2 <- plot(results2, 
               pie = pred1$error$R2, 
               groups=gr2,
               layout="spring", 
               legend.cex=.40, # scalar on legend size
               vsize=15, 
               #legend.mode = 'style2',
               border.width=2, border.color='#555555',
               minimum = 0.05,minimum = 0.05,
               color=c("#fc8d59","#e0f3f8"),
               details=TRUE,
               legend=TRUE,
               label.cex=0.9,label.scale.equal=TRUE,label.scale=FALSE
               #labels=1:7,
               #nodeNames=colnames(data)
               )

par(mfrow=c(1,1))

#Plotting interpretable distances via Multi-Dimensional Scaling: 
#https://www.ncbi.nlm.nih.gov/pmc/articles/PMC6156459/pdf/fpsyg-09-01742.pdf

#First, check which method of MDS is best for estimating the plot
library("smacof")
dissimilarity_net1 <- sim2diss(cor_auto(data))
net1_MDS <- mds(dissimilarity_net1)
head(round(net1_MDS$conf, 2))

net1_MDS_ordinal <- mds(dissimilarity_net1,type="ordinal")
net1_MDS_ratio <- mds(dissimilarity_net1,type="ratio")
net1_MDS_interval <- mds(dissimilarity_net1,type="interval")
net1_MDS_mspline <- mds(dissimilarity_net1,type="mspline")

par(mfrow=c(2,2))
plot(net1_MDS_ordinal, plot.type = "Shepard",main="Ordinal"); text(0.7,1, paste("Stress =",round(net1_MDS_ordinal$stress,2)))
plot(net1_MDS_ratio, plot.type = "Shepard",main="Ratio"); text(0.7,1, paste("Stress =",round(net1_MDS_ratio$stress,2)))
plot(net1_MDS_interval, plot.type = "Shepard",main="Interval"); text(0.7,1, paste("Stress =",round(net1_MDS_interval$stress,2)))
plot(net1_MDS_mspline, plot.type = "Shepard",main="Spline"); text(0.7,1, paste("Stress =",round(net1_MDS_mspline$stress,2)))
par(mfrow=c(1,1))

#Best is mspline
#Good alternatives are: ordinal (less parsimonious)

#MDS net with node spacing based on MDS and edges based on EBICglasso
#legible nodes
par(mfrow=c(2,2))
MDSnet <- MDSnet(graph1,
                 type = c("mspline"),
                 MDSadj = cor_auto(data),
                 stressTxt=TRUE,
                 groups=gr1,
                 color="#fee090",
                 details=FALSE,
                 legend=FALSE,
                 #labels=1:7,
                 nodeNames=colnames(data),
                 title="mspline",
                 #repulse=TRUE,repulsion=0.3,
                 vsize=5, #reduce node sizes to get better view of edges
                 label.cex=5, # scalar on label size
)

MDSnet <- MDSnet(graph1,
                 type = c("ordinal"),
                 MDSadj = cor_auto(data),
                 stressTxt=TRUE,
                 groups=gr1,
                 color="#fee090",
                 details=FALSE,
                 legend=FALSE,
                 #labels=1:7,
                 nodeNames=colnames(data),
                 title="ordinal",
                 #repulse=TRUE,repulsion=0.3,
                 vsize=5, #reduce node sizes to get better view of edges
                 label.cex=5, # scalar on label size
)

MDSnet <- MDSnet(graph1,
                 type = c("mspline"),
                 MDSadj = cor_auto(data),
                 stressTxt=TRUE,
                 groups=gr2,
                 color=c("#fc8d59","#e0f3f8"),
                 details=FALSE,
                 legend=FALSE,
                 #labels=1:7,
                 nodeNames=colnames(data),
                 title="mspline",
                 #repulse=TRUE,repulsion=0.3,
                 vsize=5, #reduce node sizes to get better view of edges
                 label.cex=5, # scalar on label size
)

MDSnet <- MDSnet(graph1,
                 type = c("ordinal"),
                 MDSadj = cor_auto(data),
                 stressTxt=TRUE,
                 groups=gr2,
                 color=c("#fc8d59","#e0f3f8"),
                 details=FALSE,
                 legend=FALSE,
                 #labels=1:7,
                 nodeNames=colnames(data),
                 title="ordinal",
                 #repulse=TRUE,repulsion=0.3,
                 vsize=5, #reduce node sizes to get better view of edges
                 label.cex=5, # scalar on label size
)
par(mfrow=c(1,1))

pdf("MDSnet.pdf", width = 10, height=6)
plot(MDSnet)
dev.off()



#bootstrapping bridge centrality with final groups
#https://paytonjjones.wordpress.com/2019/02/01/bootstrapping-bridge-centrality-using-the-bootnet-package/
#https://dial.uclouvain.be/pr/boreal/object/boreal%3A195204/datastream/PDF_01/view

boot4 <- bootnet(results2, nCores = 14,nBoots = 1000, type ='nonparametric',
                 statistics = c("bridgeExpectedInfluence","bridgeStrength","bridgeCloseness","bridgeBetweenness"),
                                communities=gr2)
plot(boot4,statistics = c("bridgeExpectedInfluence", "bridgeStrength", "bridgeCloseness","bridgeBetweenness"),plot="area",order="sample")
plot(boot4,statistics = c("bridgeExpectedInfluence", "bridgeStrength", "bridgeCloseness","bridgeBetweenness"),plot="interval",order="sample")
plot(boot4,statistics = c("bridgeExpectedInfluence", "bridgeStrength", "bridgeCloseness","bridgeBetweenness"),plot="line",order="sample")
plot(boot4,statistics = c("bridgeExpectedInfluence", "bridgeStrength", "bridgeCloseness","bridgeBetweenness"),plot="difference",differenceShowValue=TRUE)

library(gridExtra)
centrplot1 <- plot(boot1,c("strength","expectedInfluence","betweenness","closeness"), plot = "interval", order = "sample") #interpret CIs with care due to being unstable
centrplot2 <- plot(boot4,statistics = c("bridgeExpectedInfluence", "bridgeStrength", "bridgeCloseness","bridgeBetweenness"),plot="interval",order="sample")
grid.arrange(centrplot1,centrplot2)

boot5 <- bootnet(results, nCores = 14,nBoots = 1000, type ='case',
                 statistics = c("bridgeExpectedInfluence","bridgeStrength","bridgeCloseness","bridgeBetweenness"),
                 communities=gr2)
plot(boot5,  statistics = c("bridgeExpectedInfluence","bridgeStrength","bridgeCloseness","bridgeBetweenness"))
plot(boot5,  statistics = c("bridgeExpectedInfluence","bridgeStrength","bridgeCloseness","bridgeBetweenness"))
corStability(boot5)

#Final network

plot(graph2)

#to see maximum and minimum, set details=TRUE 
pdf("Figure1.pdf", width = 10, height=6)
plot(graph4)
dev.off()


MDSnet <- MDSnet(graph2,
                 type = c("mspline"),
                 MDSadj = cor_auto(data),
                 stressTxt=TRUE,
                 #repulse=TRUE,repulsion=0.3,
                 #vsize=2 #reduce node sizes to get better view of edges
)


pdf("MDSnet.pdf", width = 10, height=6)
plot(MDSnet)
dev.off()




















############### NETWORK COMPARISONS #####################


#### GENDER  ######
data_impMales<-import("Data FearCovid19 - MALES.sav")
data_impFemales<-import("Data FearCovid19 - FEMALES.sav")
#rename variables
dataMales<-data_impMales[,c("FC1","FC2","FC3","FC4","FC5","FC6","FC7")]
dataMales<-dplyr::rename(dataMales,"Afraid" = "FC1", "Umconf" = "FC2","ClammyHands" = "FC3",
             "AfraidDie" = "FC4","AnxNews" =  "FC5", "Insomnia" = "FC6", "HeartRaces" = "FC7")
headTail(dataMales)
#Change value 9 to NA (it's a 1 to 5 scale)
dataMales[dataMales == 9] <- 3

dataFemales<-data_impFemales[,c("FC1","FC2","FC3","FC4","FC5","FC6","FC7")]
dataFemales<-dplyr::rename(dataFemales,"Afraid" = "FC1", "Umconf" = "FC2","ClammyHands" = "FC3",
                  "AfraidDie" = "FC4","AnxNews" =  "FC5", "Insomnia" = "FC6", "HeartRaces" = "FC7")
headTail(dataFemales)
#Change value 9 to NA (it's a 1 to 5 scale)
dataFemales[dataFemales == 9] <- 3

#### SAMPLE  ######
data_impIran<-import("Data FearCovid19 - IRAN.sav")
data_impBangladesh<-import("Data FearCovid19 - BANGLADESH.sav")
data_impNorway<-import("Data FearCovid19 - NORWAY.sav")
#rename variables
dataIran<-data_impIran[,c("FC1","FC2","FC3","FC4","FC5","FC6","FC7")]
dataIran<-dplyr::rename(dataIran,"Afraid" = "FC1", "Umconf" = "FC2","ClammyHands" = "FC3",
                  "AfraidDie" = "FC4","AnxNews" =  "FC5", "Insomnia" = "FC6", "HeartRaces" = "FC7")
headTail(dataIran)
#Change value 9 to NA (it's a 1 to 5 scale)
dataIran[dataIran == 9] <- 3

dataBangladesh<-data_impBangladesh[,c("FC1","FC2","FC3","FC4","FC5","FC6","FC7")]
dataBangladesh<-dplyr::rename(dataBangladesh,"Afraid" = "FC1", "Umconf" = "FC2","ClammyHands" = "FC3",
                    "AfraidDie" = "FC4","AnxNews" =  "FC5", "Insomnia" = "FC6", "HeartRaces" = "FC7")
headTail(dataBangladesh)
#Change value 9 to NA (it's a 1 to 5 scale)
dataBangladesh[dataBangladesh == 9] <- 3


dataNorway<-data_impNorway[,c("FC1","FC2","FC3","FC4","FC5","FC6","FC7")]
dataNorway<-dplyr::rename(dataNorway,"Afraid" = "FC1", "Umconf" = "FC2","ClammyHands" = "FC3",
                              "AfraidDie" = "FC4","AnxNews" =  "FC5", "Insomnia" = "FC6", "HeartRaces" = "FC7")
headTail(dataNorway)
#Change value 9 to NA (it's a 1 to 5 scale)
dataNorway[dataNorway == 9] <- 3

#### AGE GROUPS #####
data_impYoung<-import("Data FearCovid19 - YOUNG.sav")
data_impMid<-import("Data FearCovid19 - MID.sav")
data_impOld<-import("Data FearCovid19 - OLD.sav")

dataYoung<-data_impYoung[,c("FC1","FC2","FC3","FC4","FC5","FC6","FC7")]
dataYoung<-dplyr::rename(dataYoung,"Afraid" = "FC1", "Umconf" = "FC2","ClammyHands" = "FC3",
                          "AfraidDie" = "FC4","AnxNews" =  "FC5", "Insomnia" = "FC6", "HeartRaces" = "FC7")
headTail(dataYoung)
#Change value 9 to NA (it's a 1 to 5 scale)
dataYoung[dataYoung == 9] <- 3

dataMid<-data_impMid[,c("FC1","FC2","FC3","FC4","FC5","FC6","FC7")]
dataMid<-dplyr::rename(dataMid,"Afraid" = "FC1", "Umconf" = "FC2","ClammyHands" = "FC3",
                         "AfraidDie" = "FC4","AnxNews" =  "FC5", "Insomnia" = "FC6", "HeartRaces" = "FC7")
headTail(dataMid)
#Change value 9 to NA (it's a 1 to 5 scale)
dataMid[dataMid == 9] <- 3

dataOld<-data_impOld[,c("FC1","FC2","FC3","FC4","FC5","FC6","FC7")]
dataOld<-dplyr::rename(dataOld,"Afraid" = "FC1", "Umconf" = "FC2","ClammyHands" = "FC3",
                       "AfraidDie" = "FC4","AnxNews" =  "FC5", "Insomnia" = "FC6", "HeartRaces" = "FC7")
headTail(dataOld)
#Change value 9 to NA (it's a 1 to 5 scale)
dataOld[dataOld == 9] <- 3







Res_1 <- NCT(dataMales,dataFemales, #gamma=0,
             it=10000, binary.data = FALSE, paired=FALSE,
             test.edges=TRUE,edges="all",p.adjust.method = "bonferroni",
             test.centrality=TRUE,centrality=c("all"),
             communities=c(1,1,2,1,1,2,2),useCommunities="all",
             )

summary(Res_1)

#network structure invariance test 
plot(Res_1, what="network")

#global strength invariance test :
plot(Res_1, what="strength")

#edge invariance test:
# Note that two distributions are plotted
plot(Res_1, what="edge")

#centrality invariance test :
plot(Res_1, what="centrality") 


#Samples

Res_2a <- NCT(dataIran,dataBangladesh, #gamma=0,
             it=10000, binary.data = FALSE, paired=FALSE,
             test.edges=TRUE,edges="all",p.adjust.method = "bonferroni",
             test.centrality=TRUE,centrality=c("all"),
             communities=c(1,1,2,1,1,2,2),useCommunities="all",
)

summary(Res_2a)

#network structure invariance test 
plot(Res_2a, what="network")

#global strength invariance test :
plot(Res_2a, what="strength")

#edge invariance test:
# Note that two distributions are plotted
plot(Res_2a, what="edge")

#centrality invariance test :
plot(Res_2a, what="centrality")


Res_2b <- NCT(dataIran,dataNorway, #gamma=0,
             it=10000, binary.data = FALSE, paired=FALSE,
             test.edges=TRUE,edges="all",p.adjust.method = "bonferroni",
             test.centrality=TRUE,centrality=c("all"),
             communities=c(1,1,2,1,1,2,2),useCommunities="all",
)

summary(Res_2b)

#network structure invariance test 
plot(Res_2b, what="network")

#global strength invariance test :
plot(Res_2b, what="strength")

#edge invariance test:
# Note that two distributions are plotted
plot(Res_2b, what="edge")

#centrality invariance test :
plot(Res_2b, what="centrality")

Res_2c <- NCT(dataBangladesh,dataNorway, #gamma=0,
              it=10000, binary.data = FALSE, paired=FALSE,
              test.edges=TRUE,edges="all",p.adjust.method = "bonferroni",
              test.centrality=TRUE,centrality=c("all"),
              communities=c(1,1,2,1,1,2,2),useCommunities="all",
)

summary(Res_2c)

#network structure invariance test 
plot(Res_2c, what="network")

#global strength invariance test :
plot(Res_2c, what="strength")

#edge invariance test:
# Note that two distributions are plotted
plot(Res_2c, what="edge")

#centrality invariance test :
plot(Res_2c, what="centrality")


#age groups

Res_3a <- NCT(dataYoung,dataMid, #gamma=0,
              it=10000, binary.data = FALSE, paired=FALSE,
              test.edges=TRUE,edges="all",p.adjust.method = "bonferroni",
              test.centrality=TRUE,centrality=c("all"),
              communities=c(1,1,2,1,1,2,2),useCommunities="all",
)

summary(Res_3a)

#network structure invariance test 
plot(Res_3a, what="network")

#global strength invariance test :
plot(Res_3a, what="strength")

#edge invariance test:
# Note that two distributions are plotted
plot(Res_3a, what="edge")

#centrality invariance test :
plot(Res_3a, what="centrality")


Res_3b <- NCT(dataMid,dataOld, #gamma=0,
              it=10000, binary.data = FALSE, paired=FALSE,
              test.edges=TRUE,edges="all",p.adjust.method = "bonferroni",
              test.centrality=TRUE,centrality=c("all"),
              communities=c(1,1,2,1,1,2,2),useCommunities="all",
)

summary(Res_3b)

#network structure invariance test 
plot(Res_3b, what="network")

#global strength invariance test :
plot(Res_3b, what="strength")

#edge invariance test:
# Note that two distributions are plotted
plot(Res_3b, what="edge")

#centrality invariance test :
plot(Res_3b, what="centrality")


Res_3c <- NCT(dataMid,dataYoung, #gamma=0,
              it=10000, binary.data = FALSE, paired=FALSE,
              test.edges=TRUE,edges="all",p.adjust.method = "bonferroni",
              test.centrality=TRUE,centrality=c("all"),
              communities=c(1,1,2,1,1,2,2),useCommunities="all",
)

summary(Res_3c)

#network structure invariance test 
plot(Res_3c, what="network")

#global strength invariance test :
plot(Res_3c, what="strength")

#edge invariance test:
# Note that two distributions are plotted
plot(Res_3c, what="edge")

#centrality invariance test :
plot(Res_3c, what="centrality")






####Estimate networks of males and females for comparison
# info at: https://cran.r-project.org/web/packages/EstimateGroupNetwork/EstimateGroupNetwork.pdf
#group estimation of networks, standard method (if time extensive, remove "strategy = "simultaneous"")

nrow(dataMales)
nrow(dataFemales)

nrow(dataIran)
nrow(dataBangladesh)
nrow(dataNorway)

nrow(dataYoung)
nrow(dataMid)
nrow(dataOld)

dataGender <- list(males = dataMales, females = dataFemales)

recnets <- EstimateGroupNetwork(dataGender, inputType = "list.of.dataframes", 
                                method = "InformationCriterion",ncores = (parallel::detectCores()-1), criterion = "ebic", 
                                count.unique = TRUE, strategy = "simultaneous",optimize = TRUE,
                                simplifyOutput=FALSE #required for bootstrap to work
                                )



#alternative method: Using k-fold crossvalidation (k = 10 by default)
recnetsCV <- EstimateGroupNetwork(dataGender, inputType = "list.of.dataframes", 
                                  method = "crossvalidation",ncores = (parallel::detectCores()-1), seed = 65432, k = 10,
                                  simplifyOutput=FALSE #required for bootstrap to work
                                  )

#bootstrapp it
boot_Gender_net <- GroupNetworkBoot(data_list = dataGender, groupNetwork = recnets,
                                 nboots = 500, bootSeed = 65432, ncores = (parallel::detectCores()-2))

# use BootTable to obtain a table with information for each boostrapped edge
BootTable(boot_Gender_net)
## Use GroupBootPlot to obtain plots as a list with each group plot as one element
GroupBootPlot(boot_Gender_net)
## Get plot for a subset of edges (here: all edges including A1). Also check Groupnames
#GroupBootPlot(boot_Gender_net, edges.x = "A1", edges.y = c("A2", "A3", "A4", "A5"),
#              GroupNames = c("Females", "Males"), GroupNamesCheck = TRUE, legend.position = "top")


####Estimate networks of Iran, Bangladesh and Norway for comparison
dataCountry <- list(Iran = dataIran, Bangladesh = dataBangladesh, Norway = dataNorway)

recnetsCountry <- EstimateGroupNetwork(dataCountry, inputType = "list.of.dataframes", 
                                       method = "InformationCriterion",ncores = (parallel::detectCores()-1), criterion = "ebic", 
                                       count.unique = TRUE, strategy = "simultaneous",optimize = TRUE,
                                       simplifyOutput=FALSE #required for bootstrap to work
)

#alternative method: Using k-fold crossvalidation (k = 10 by default)
recnetsCVCountry <- EstimateGroupNetwork(dataCountry, inputType = "list.of.dataframes", 
                                         method = "crossvalidation",ncores = (parallel::detectCores()-1), seed = 65432, k = 10,
                                         simplifyOutput=FALSE #required for bootstrap to work
)

#bootstrapp it
boot_Country_net <- GroupNetworkBoot(data_list = dataCountry, groupNetwork = recnetsCountry,
                                     nboots = 10, bootSeed = 1234, ncores = (parallel::detectCores()-2), seed = 65432)

# use BootTable to obtain a table with information for each boostrapped edge
BootTable(boot_Country_net)
## Use GroupBootPlot to obtain plots as a list with each group plot as one element
GroupBootPlot(boot_Country_net)
## Get plot for a subset of edges (here: all edges including A1). Also check Groupnames
#GroupBootPlot(boot_Country_net, edges.x = "A1", edges.y = c("A2", "A3", "A4", "A5"),
#              GroupNames = c("Females", "Males"), GroupNamesCheck = TRUE, legend.position = "top")




####Estimate networks of young, medium and old age for comparison
dataAge <- list(Young = dataYoung, Mid = dataMid, Old = dataOld)

recnetsAge <- EstimateGroupNetwork(dataAge, inputType = "list.of.dataframes", 
                                   method = "InformationCriterion",ncores = (parallel::detectCores()-1), criterion = "ebic", 
                                   count.unique = TRUE, strategy = "simultaneous",optimize = TRUE,
                                   simplifyOutput=FALSE #required for bootstrap to work
)

#alternative method: Using k-fold crossvalidation (k = 10 by default)
recnetsCVAge <- EstimateGroupNetwork(dataAge, inputType = "list.of.dataframes", 
                                     method = "crossvalidation",ncores = (parallel::detectCores()-1), seed = 65432, k = 10,
                                     simplifyOutput=FALSE #required for bootstrap to work
)

#bootstrapp it
boot_Age_net <- GroupNetworkBoot(data_list = dataAge, groupNetwork = recnetsAge,
                                 nboots = 10, bootSeed = 1234, ncores = (parallel::detectCores()-2), seed = 65432)

# use BootTable to obtain a table with information for each boostrapped edge
BootTable(boot_Age_net)
## Use GroupBootPlot to obtain plots as a list with each group plot as one element
GroupBootPlot(boot_Age_net)
## Get plot for a subset of edges (here: all edges including A1). Also check Groupnames
#GroupBootPlot(boot_Country_net, edges.x = "A1", edges.y = c("A2", "A3", "A4", "A5"),
#              GroupNames = c("Females", "Males"), GroupNamesCheck = TRUE, legend.position = "top")



# Network plots by gender, country and age:

#node predictability
type=rep('g', 7) #g=gaussian, 17 = number of nodes in the network
fitmales<-mgm(dataMales,
              type=type, 
              level=rep(1,7)
)
fitfemales<-mgm(dataFemales,
                type=type, 
                level=rep(1,7)
)
fitiran<-mgm(dataIran,
             type=type, 
             level=rep(1,7)
)
fitbangladesh<-mgm(dataBangladesh,
                   type=type, 
                   level=rep(1,7)
)
fitnorway<-mgm(dataNorway,
               type=type, 
               level=rep(1,7)
)

fityoung<-mgm(dataYoung,
               type=type, 
               level=rep(1,7)
)

fitmid<-mgm(dataMid,
               type=type, 
               level=rep(1,7)
)

fitold<-mgm(dataOld,
               type=type, 
               level=rep(1,7)
)

predmales<- predict(fitmales, dataMales)
predfemales<- predict(fitfemales, dataFemales)

prediran<- predict(fitiran, dataIran)
predbangladesh<- predict(fitbangladesh, dataBangladesh)
prednorway<- predict(fitnorway, dataNorway)

predYoung <- predict(fityoung, dataYoung)
predMid <- predict(fitmid, dataMid)
predOld <- predict(fitold, dataOld)

#Gender - almost no differences, discarded from the paper

Layout <- averageLayout(recnets$network$males,recnets$network$females)
layout(t(1:2))
qgraph(recnets$network$males, layout = Layout, title = "Males",
       theme="colorblind", pie=predmales$error$R2,
       border.width=2, vsize=10, border.color='#555555', label.color="#000000",
       groups=gr2,color=c("#fc8d59","#e0f3f8"))
qgraph(recnets$network$females, layout = Layout, title = "Females",
       theme="colorblind", pie=predfemales$error$R2,
       border.width=2, vsize=10, border.color='#555555', label.color="#000000",
       groups=gr2,color=c("#fc8d59","#e0f3f8"))
layout(t(1:1))

#cross-validation: Almost no changes, discarded from the paper
Layout <- averageLayout(recnetsCV$males,recnetsCV$females)
layout(t(1:2))
qgraph(recnetsCV$network$males, layout = Layout, title = "Males",
       theme="colorblind", pie=predmales$error$R2,
       border.width=2, vsize=10, border.color='#555555', label.color="#000000",
       groups=gr2,color=c("#fc8d59","#e0f3f8"))
qgraph(recnetsCV$network$females, layout = Layout, title = "Females",
       theme="colorblind", pie=predfemales$error$R2,
       border.width=2, vsize=10, border.color='#555555', label.color="#000000",
       groups=gr2,color=c("#fc8d59","#e0f3f8"))
layout(t(1:1))

#centrality
centrality(list(Males = recnets$network$males,Females = recnets$network$females))

centralityPlot(
  list(Males = recnets$network$males,Females = recnets$network$females), 
  include = c("Strength","ExpectedInfluence","Closeness","Betweenness")
)


#country - relevant differences, included in paper

Layout <- averageLayout(recnetsCountry$network$Iran,recnetsCountry$network$Bangladesh,recnetsCountry$network$Norway)
#layout(t(1:6))
par(mfrow=c(2,3))
qgraph(recnetsCountry$network$Iran, layout = Layout, title = "Iran (1 cluster)",
       theme="colorblind", pie=prediran$error$R2,
       border.width=2, vsize=20, border.color='#555555', label.color="#c",
       groups=gr1,color="#fee090",legend=FALSE,labels=colnames(data),label.cex=1,label.scale.equal=TRUE,label.scale=FALSE)
qgraph(recnetsCountry$network$Bangladesh, layout = Layout, title = "Bangladesh (1 cluster)",
       theme="colorblind", pie=predbangladesh$error$R2,
       border.width=2, vsize=20, border.color='#555555', label.color="#000000",
       groups=gr1,color="#fee090",legend=FALSE,labels=colnames(data),label.cex=1,label.scale.equal=TRUE,label.scale=FALSE)
qgraph(recnetsCountry$network$Norway, layout = Layout, title = "Norway (1 cluster)",
       theme="colorblind", pie=prednorway$error$R2,
       border.width=2, vsize=20, border.color='#555555', label.color="#000000",
       groups=gr1,color="#fee090",legend=FALSE,labels=colnames(data),label.cex=1,label.scale.equal=TRUE,label.scale=FALSE)

qgraph(recnetsCountry$network$Iran, layout = Layout, title = "Iran (2 clusters)",
       theme="colorblind", pie=prediran$error$R2,
       border.width=2, vsize=20, border.color='#555555', label.color="#000000",
       groups=gr2,color=c("#fc8d59","#e0f3f8"),legend=FALSE,labels=colnames(data),label.cex=1,label.scale.equal=TRUE,label.scale=FALSE)
qgraph(recnetsCountry$network$Bangladesh, layout = Layout, title = "Bangladesh (2 clusters)",
       theme="colorblind", pie=predbangladesh$error$R2,
       border.width=2, vsize=20, border.color='#555555', label.color="#000000",
       groups=gr2,color=c("#fc8d59","#e0f3f8"),legend=FALSE,labels=colnames(data),label.cex=1,label.scale.equal=TRUE,label.scale=FALSE)
qgraph(recnetsCountry$network$Norway, layout = Layout, title = "Norway (2 clusters)",
       theme="colorblind", pie=prednorway$error$R2,
       border.width=2, vsize=20, border.color='#555555', label.color="#000000",
       groups=gr2,color=c("#fc8d59","#e0f3f8"),legend=FALSE,labels=colnames(data),label.cex=1,label.scale.equal=TRUE,label.scale=FALSE)
par(mfrow=c(1,1))
#♠layout(t(1:1))


#centrality
centrality(list(Iran = recnetsCountry$network$Iran,Bangladesh = recnetsCountry$network$Bangladesh, Norway =  recnetsCountry$network$Norway))

centralityPlot(
  list(Iran = recnetsCountry$network$Iran,Bangladesh = recnetsCountry$network$Bangladesh, Norway =  recnetsCountry$network$Norway), 
  include = c("Strength","ExpectedInfluence","Closeness","Betweenness")
)


#Age - almost no differences, discarded from the paper


Layout <- averageLayout(recnetsAge$network$Young,recnetsAge$network$Mid,recnetsAge$network$Old)
layout(t(1:3))
qgraph(recnetsAge$network$Young, layout = Layout, title = "Young",
       theme="colorblind", pie=predYoung$error$R2,
       border.width=2, vsize=10, border.color='#555555', label.color="#000000",
       groups=gr2,color=c("#fc8d59","#e0f3f8"))
qgraph(recnetsAge$network$Mid, layout = Layout, title = "Mid",
       theme="colorblind", pie=predMid$error$R2,
       border.width=2, vsize=10, border.color='#555555', label.color="#000000",
       groups=gr2,color=c("#fc8d59","#e0f3f8"))
qgraph(recnetsAge$network$Old, layout = Layout, title = "Old",
       theme="colorblind", pie=predOld$error$R2,
       border.width=2, vsize=10, border.color='#555555', label.color="#000000",
       groups=gr2,color=c("#fc8d59","#e0f3f8"))
layout(t(1:1))


#centrality
centrality(list(Young = recnetsAge$network$Young,Mid = recnetsAge$network$Mid, Old =  recnetsAge$network$Old))

centralityPlot(
  list(Young = recnetsAge$network$Young,Mid = recnetsAge$network$Mid, Old =  recnetsAge$network$Old), 
  include = c("Strength","ExpectedInfluence","Closeness","Betweenness")
)






###################################

# power analyses for each network #

###################################

#power analysis with new network
simResMales <- netSimulator(recnets$network$males,
                        dataGenerator = ggmGenerator(ordinal = TRUE, nLevels = 5),
                        default = "ggmModSelect",
                        nCases = c(5000,10000,11000,20000,50000),
                        #tuning = 0,
                        nReps = 500,
                        nCores = detectCores()-2
)

#simRes2
plot(simResMales) #now all are good
plot(simResMales,yvar = c("ExpectedInfluence","closeness","betweenness","strength")) #all good again

simResReplicationMales <- replicationSimulator(recnets$network$males,
                                           dataGenerator = ggmGenerator(ordinal = TRUE, nLevels = 5),
                                           default = "ggmModSelect",
                                           nCases = c(5000,10000,11000,20000,50000),
                                           tuning = 0,
                                           nReps = 500,
                                           nCores = detectCores()-2
)

plot(simResReplicationMales) #now all are good
plot(simResReplicationMales,yvar = c("closeness","betweenness","strength")) #all good again

simResFemales <- netSimulator(recnets$network$females,
                            dataGenerator = ggmGenerator(ordinal = TRUE, nLevels = 5),
                            default = "ggmModSelect",
                            nCases = c(5000,10000,11000,20000,50000),
                            tuning = 0,
                            nReps = 500,
                            nCores = detectCores()-2
)

#simRes2
plot(simResFemales) #now all are good
plot(simResFemales,yvar = c("ExpectedInfluence","closeness","betweenness","strength")) #all good again

simResReplicationFemales <- replicationSimulator(recnets$network$females,
                                               dataGenerator = ggmGenerator(ordinal = TRUE, nLevels = 5),
                                               default = "ggmModSelect",
                                               nCases = c(5000,10000,11000,20000,50000),
                                               tuning = 0,
                                               nReps = 500,
                                               nCores = detectCores()-2
)

plot(simResReplicationFemales) #now all are good
plot(simResReplicationFemales,yvar = c("closeness","betweenness","strength")) #all good again


#https://github.com/DennyBorsboom/NatureMethodsPrimer_NetworkAnalysis/blob/main/Personality/ApplicationsPersonality.R
# the following code combines them in a single figure, like we in the paper
# using ggplot2
SimMales_mlt <- select(simResMales, nCases, sensitivity:correlation) %>%
  melt(id.vars = "nCases") %>%
  mutate(network = "Males")

SimFemales_mlt <- select(simResFemales, nCases, sensitivity:correlation) %>%
  melt(id.vars = "nCases") %>%
  mutate(network = "Females")

SimGender_mlt <- rbind(SimMales_mlt, SimFemales_mlt)
SimGender_mlt$network <- factor(SimGender_mlt$network, levels = c("Males", "Females"))

# colorblind palette
cbbPaletteGender <- c("#E1D57F", "#7FA4E1")#, "#009E73")
cbbPaletteGender2 <- c("#E69F00", "#56B4E9")#, "#009E73")


repSimGender_plt <- ggplot(SimGender_mlt, aes(x = factor(nCases), y = value, fill = network)) +
  geom_boxplot() +
  facet_wrap(~variable) +
  xlab("sample size") + 
  ylab("") +
  scale_colour_manual(values = cbbPaletteGender) +
  scale_fill_manual(values = cbbPaletteGender) +
  theme_bw() + 
  theme(legend.text = element_text(size = 15), 
        legend.title = element_text(size = 15),
        strip.text.x = element_text(size = 15),
        axis.text.x = element_text(size = 11, angle = 90),
        axis.title.x =  element_text(size = 15),
        legend.key.size = unit(1, "in"),
        axis.text.y = element_text(size = 9)
  )


repSimGender_plt

#now with centrality power indices
SimMalesCentrality_mlt <- select(simResMales, nCases, strength:ExpectedInfluence) %>%
  melt(id.vars = "nCases") %>%
  mutate(network = "Males")

SimFemalesCentrality_mlt <- select(simResFemales, nCases, strength:ExpectedInfluence) %>%
  melt(id.vars = "nCases") %>%
  mutate(network = "Females")

SimGenderCentrality_mlt <- rbind(SimMalesCentrality_mlt, SimFemalesCentrality_mlt)
SimGenderCentrality_mlt$network <- factor(SimGenderCentrality_mlt$network, levels = c("Males", "Females"))

# colorblind palette
cbbPaletteGender <- c("#E1D57F", "#7FA4E1")#, "#009E73")
cbbPaletteGender2 <- c("#E69F00", "#56B4E9")#, "#009E73")


repSimGenderCentrality_plt <- ggplot(SimGenderCentrality_mlt, aes(x = factor(nCases), y = value, fill = network)) +
  geom_boxplot() +
  facet_wrap(~variable) +
  xlab("sample size") + 
  ylab("") +
  scale_colour_manual(values = cbbPaletteGender) +
  scale_fill_manual(values = cbbPaletteGender) +
  theme_bw() + 
  theme(legend.text = element_text(size = 15), 
        legend.title = element_text(size = 15),
        strip.text.x = element_text(size = 15),
        axis.text.x = element_text(size = 11, angle = 90),
        axis.title.x =  element_text(size = 15),
        legend.key.size = unit(1, "in"),
        axis.text.y = element_text(size = 9)
  )


repSimGenderCentrality_plt


#now with replication indices
SimRepMales_mlt <- select(simResReplicationMales, nCases, correlationNonZero:replicatedZeroes) %>%
  melt(id.vars = "nCases") %>%
  mutate(network = "Males")

SimRepFemales_mlt <- select(simResReplicationFemales, nCases, correlationNonZero:replicatedZeroes) %>%
  melt(id.vars = "nCases") %>%
  mutate(network = "Females")

SimRepGender_mlt <- rbind(SimRepMales_mlt, SimRepFemales_mlt)
SimRepGender_mlt$network <- factor(SimRepGender_mlt$network, levels = c("Males", "Females"))

# colorblind palette
cbbPaletteGender <- c("#E1D57F", "#7FA4E1")#, "#009E73")
cbbPaletteGender2 <- c("#E69F00", "#56B4E9")#, "#009E73")


repSimRepGender_plt <- ggplot(SimRepGender_mlt, aes(x = factor(nCases), y = value, fill = network)) +
  geom_boxplot() +
  facet_wrap(~variable) +
  xlab("sample size") + 
  ylab("") +
  scale_colour_manual(values = cbbPaletteGender) +
  scale_fill_manual(values = cbbPaletteGender) +
  theme_bw() + 
  theme(legend.text = element_text(size = 15), 
        legend.title = element_text(size = 15),
        strip.text.x = element_text(size = 15),
        axis.text.x = element_text(size = 11, angle = 90),
        axis.title.x =  element_text(size = 15),
        legend.key.size = unit(1, "in"),
        axis.text.y = element_text(size = 9)
  )


repSimRepGender_plt

#now with centrality indices

SimRepMalesCentrality_mlt <- select(simResReplicationMales, nCases, strength:betweenness) %>%
  melt(id.vars = "nCases") %>%
  mutate(network = "Males")

SimRepFemalesCentrality_mlt <- select(simResReplicationFemales, nCases, strength:betweenness) %>%
  melt(id.vars = "nCases") %>%
  mutate(network = "Females")



SimRepGenderCentrality_mlt <- rbind(SimRepMalesCentrality_mlt, SimRepFemalesCentrality_mlt)
SimRepGenderCentrality_mlt$network <- factor(SimRepGenderCentrality_mlt$network, levels = c("Males", "Females"))

# colorblind palette
cbbPaletteGender <- c("#E1D57F", "#7FA4E1")#, "#009E73")
cbbPaletteGender2 <- c("#E69F00", "#56B4E9")#, "#009E73")


repSimRepGenderCentrality_plt <- ggplot(SimRepGenderCentrality_mlt, aes(x = factor(nCases), y = value, fill = network)) +
  geom_boxplot() +
  facet_wrap(~variable) +
  xlab("sample size") + 
  ylab("") +
  scale_colour_manual(values = cbbPaletteGender) +
  scale_fill_manual(values = cbbPaletteGender) +
  theme_bw() + 
  theme(legend.text = element_text(size = 15), 
        legend.title = element_text(size = 15),
        strip.text.x = element_text(size = 15),
        axis.text.x = element_text(size = 11, angle = 90),
        axis.title.x =  element_text(size = 15),
        legend.key.size = unit(1, "in"),
        axis.text.y = element_text(size = 9)
  )


repSimRepGenderCentrality_plt



#country




simResIran <- netSimulator(recnetsCountry$network$Iran,
                            dataGenerator = ggmGenerator(ordinal = TRUE, nLevels = 5),
                            default = "ggmModSelect",
                            nCases = c(2000,3500,5000,10000,20000),
                            tuning = 0,
                            nReps = 500,
                            nCores = detectCores()-2
)

#simRes2
plot(simResIran) #now all are good
plot(simResIran,yvar = c("ExpectedInfluence","closeness","betweenness","strength")) #all good again

simResReplicationIran <- replicationSimulator(recnetsCountry$network$Iran,
                                               dataGenerator = ggmGenerator(ordinal = TRUE, nLevels = 5),
                                               default = "ggmModSelect",
                                               nCases = c(2000,3500,5000,10000,20000),
                                               tuning = 0,
                                               nReps = 500,
                                               nCores = detectCores()-2
)

plot(simResReplicationIran) #now all are good
plot(simResReplicationIran,yvar = c("closeness","betweenness","strength")) #all good again


simResBangladesh <- netSimulator(recnetsCountry$network$Bangladesh,
                            dataGenerator = ggmGenerator(ordinal = TRUE, nLevels = 5),
                            default = "ggmModSelect",
                            nCases = c(2000,3500,5000,10000,20000),
                            tuning = 0,
                            nReps = 500,
                            nCores = detectCores()-2
)

#simRes2
plot(simResBangladesh) #now all are good
plot(simResBangladesh,yvar = c("ExpectedInfluence","closeness","betweenness","strength")) #all good again


simResReplicationBangladesh <- replicationSimulator(recnetsCountry$network$Bangladesh,
                                               dataGenerator = ggmGenerator(ordinal = TRUE, nLevels = 5),
                                               default = "ggmModSelect",
                                               nCases = c(2000,3500,5000,10000,20000),
                                               tuning = 0,
                                               nReps = 500,
                                               nCores = detectCores()-2
)

plot(simResReplicationBangladesh) #now all are good
plot(simResReplicationBangladesh,yvar = c("closeness","betweenness","strength")) #all good again

simResNorway <- netSimulator(recnetsCountry$network$Norway,
                             dataGenerator = ggmGenerator(ordinal = TRUE, nLevels = 5),
                             default = "ggmModSelect",
                             nCases = c(2000,3500,5000,10000,20000),
                             tuning = 0,
                             nReps = 500,
                             nCores = detectCores()-2
)

#simRes2
plot(simResNorway) #now all are good
plot(simResNorway,yvar = c("ExpectedInfluence","closeness","betweenness","strength")) #all good again

simResReplicationNorway <- replicationSimulator(recnetsCountry$network$Norway,
                                                    dataGenerator = ggmGenerator(ordinal = TRUE, nLevels = 5),
                                                    default = "ggmModSelect",
                                                    nCases = c(2000,3500,5000,10000,20000),
                                                    tuning = 0,
                                                    nReps = 500,
                                                    nCores = detectCores()-2
)

plot(simResReplicationNorway) #now all are good
plot(simResReplicationNorway,yvar = c("closeness","betweenness","strength")) #all good again

#all countries in a single plot
SimRepIran_mlt <- select(simResIran, nCases, sensitivity:correlation) %>%
  melt(id.vars = "nCases") %>%
  mutate(network = "Iran")

SimRepBangladesh_mlt <- select(simResBangladesh, nCases, sensitivity:correlation) %>%
  melt(id.vars = "nCases") %>%
  mutate(network = "Bangladesh")

SimRepNorway_mlt <- select(simResNorway, nCases, sensitivity:correlation) %>%
  melt(id.vars = "nCases") %>%
  mutate(network = "Norway")

SimRepCountry_mlt <- rbind(SimRepIran_mlt, SimRepBangladesh_mlt, SimRepNorway_mlt)
SimRepCountry_mlt$network <- factor(SimRepCountry_mlt$network, levels = c("Iran", "Bangladesh", "Norway"))

# colorblind palette
cbbPaletteCountry <- c("#FF968A", "#97C1A9", "#A5C8E4")


repRepSimCountry_plt <- ggplot(SimRepCountry_mlt, aes(x = factor(nCases), y = value, fill = network)) +
  geom_boxplot() +
  facet_wrap(~variable) +
  xlab("sample size") + 
  ylab("") +
  scale_colour_manual(values = cbbPaletteCountry) +
  scale_fill_manual(values = cbbPaletteCountry) +
  theme_bw() + 
  theme(legend.text = element_text(size = 15), 
        legend.title = element_text(size = 15),
        strip.text.x = element_text(size = 15),
        axis.text.x = element_text(size = 11, angle = 90),
        axis.title.x =  element_text(size = 15),
        legend.key.size = unit(1, "in"),
        axis.text.y = element_text(size = 9)
  )


repRepSimCountry_plt

#now with centrality indices
SimRepIranCentrality_mlt <- select(simResIran, nCases, strength:ExpectedInfluence) %>%
  melt(id.vars = "nCases") %>%
  mutate(network = "Iran")

SimRepBangladeshCentrality_mlt <- select(simResBangladesh, nCases, strength:ExpectedInfluence) %>%
  melt(id.vars = "nCases") %>%
  mutate(network = "Bangladesh")

SimRepNorwayCentrality_mlt <- select(simResNorway, nCases, strength:ExpectedInfluence) %>%
  melt(id.vars = "nCases") %>%
  mutate(network = "Norway")

SimRepCountryCentrality_mlt <- rbind(SimRepIranCentrality_mlt, SimRepBangladeshCentrality_mlt, SimRepNorwayCentrality_mlt)
SimRepCountryCentrality_mlt$network <- factor(SimRepCountryCentrality_mlt$network, levels = c("Iran", "Bangladesh", "Norway"))

# colorblind palette
cbbPaletteCountry <- c("#FF968A", "#97C1A9", "#A5C8E4")


repRepSimCountryCentrality_plt <- ggplot(SimRepCountryCentrality_mlt, aes(x = factor(nCases), y = value, fill = network)) +
  geom_boxplot() +
  facet_wrap(~variable) +
  xlab("sample size") + 
  ylab("") +
  scale_colour_manual(values = cbbPaletteCountry) +
  scale_fill_manual(values = cbbPaletteCountry) +
  theme_bw() + 
  theme(legend.text = element_text(size = 15), 
        legend.title = element_text(size = 15),
        strip.text.x = element_text(size = 15),
        axis.text.x = element_text(size = 11, angle = 90),
        axis.title.x =  element_text(size = 15),
        legend.key.size = unit(1, "in"),
        axis.text.y = element_text(size = 9)
  )


repRepSimCountryCentrality_plt

#now with replication indices
SimRepIran_mlt <- select(simResReplicationIran, nCases, correlationNonZero:replicatedZeroes) %>%
  melt(id.vars = "nCases") %>%
  mutate(network = "Iran")

SimRepBangladesh_mlt <- select(simResReplicationBangladesh, nCases, correlationNonZero:replicatedZeroes) %>%
  melt(id.vars = "nCases") %>%
  mutate(network = "Bangladesh")

SimRepNorway_mlt <- select(simResReplicationNorway, nCases, correlationNonZero:replicatedZeroes) %>%
  melt(id.vars = "nCases") %>%
  mutate(network = "Norway")

SimRepCountry_mlt <- rbind(SimRepIran_mlt, SimRepBangladesh_mlt, SimRepNorway_mlt)
SimRepCountry_mlt$network <- factor(SimRepCountry_mlt$network, levels = c("Iran", "Bangladesh", "Norway"))

# colorblind palette
cbbPaletteCountry <- c("#FF968A", "#97C1A9", "#A5C8E4")


repRepSimCountry_plt <- ggplot(SimRepCountry_mlt, aes(x = factor(nCases), y = value, fill = network)) +
  geom_boxplot() +
  facet_wrap(~variable) +
  xlab("sample size") + 
  ylab("") +
  scale_colour_manual(values = cbbPaletteCountry) +
  scale_fill_manual(values = cbbPaletteCountry) +
  theme_bw() + 
  theme(legend.text = element_text(size = 15), 
        legend.title = element_text(size = 15),
        strip.text.x = element_text(size = 15),
        axis.text.x = element_text(size = 11, angle = 90),
        axis.title.x =  element_text(size = 15),
        legend.key.size = unit(1, "in"),
        axis.text.y = element_text(size = 9)
  )


repRepSimCountry_plt

#now with centrality indices
SimRepIranCentrality_mlt <- select(simResReplicationIran, nCases, strength:betweenness) %>%
  melt(id.vars = "nCases") %>%
  mutate(network = "Iran")

SimRepBangladeshCentrality_mlt <- select(simResReplicationBangladesh, nCases, strength:betweenness) %>%
  melt(id.vars = "nCases") %>%
  mutate(network = "Bangladesh")

SimRepNorwayCentrality_mlt <- select(simResReplicationNorway, nCases, strength:betweenness) %>%
  melt(id.vars = "nCases") %>%
  mutate(network = "Norway")

SimRepCountryCentrality_mlt <- rbind(SimRepIranCentrality_mlt, SimRepBangladeshCentrality_mlt, SimRepNorwayCentrality_mlt)
SimRepCountryCentrality_mlt$network <- factor(SimRepCountryCentrality_mlt$network, levels = c("Iran", "Bangladesh", "Norway"))

# colorblind palette
cbbPaletteCountry <- c("#FF968A", "#97C1A9", "#A5C8E4")


repRepSimCountryCentrality_plt <- ggplot(SimRepCountryCentrality_mlt, aes(x = factor(nCases), y = value, fill = network)) +
  geom_boxplot() +
  facet_wrap(~variable) +
  xlab("sample size") + 
  ylab("") +
  scale_colour_manual(values = cbbPaletteCountry) +
  scale_fill_manual(values = cbbPaletteCountry) +
  theme_bw() + 
  theme(legend.text = element_text(size = 15), 
        legend.title = element_text(size = 15),
        strip.text.x = element_text(size = 15),
        axis.text.x = element_text(size = 11, angle = 90),
        axis.title.x =  element_text(size = 15),
        legend.key.size = unit(1, "in"),
        axis.text.y = element_text(size = 9)
  )


repRepSimCountryCentrality_plt


#age


simResYoung <- netSimulator(recnetsAge$network$Young,
                           dataGenerator = ggmGenerator(ordinal = TRUE, nLevels = 5),
                           default = "ggmModSelect",
                           nCases = c(2000,2500,8000,13000,20000),
                           tuning = 0,
                           nReps = 500,
                           nCores = detectCores()-2
)

#simRes2
plot(simResYoung) #now all are good
plot(simResYoung,yvar = c("ExpectedInfluence","closeness","betweenness","strength")) #all good again

simResReplicationYoung <- replicationSimulator(recnetsAge$network$Young,
                                              dataGenerator = ggmGenerator(ordinal = TRUE, nLevels = 5),
                                              default = "ggmModSelect",
                                              nCases = c(2000,2500,8000,13000,20000),
                                              tuning = 0,
                                              nReps = 500,
                                              nCores = detectCores()-2
)

plot(simResReplicationYoung) #now all are good
plot(simResReplicationYoung,yvar = c("closeness","betweenness","strength")) #all good again


simResMid <- netSimulator(recnetsAge$network$Mid,
                                 dataGenerator = ggmGenerator(ordinal = TRUE, nLevels = 5),
                                 default = "ggmModSelect",
                                 nCases = c(2000,2500,8000,13000,20000),
                                 tuning = 0,
                                 nReps = 500,
                                 nCores = detectCores()-2
)

#simRes2
plot(simResMid) #now all are good
plot(simResMid,yvar = c("ExpectedInfluence","closeness","betweenness","strength")) #all good again


simResReplicationMid <- replicationSimulator(recnetsAge$network$Mid,
                                                    dataGenerator = ggmGenerator(ordinal = TRUE, nLevels = 5),
                                                    default = "ggmModSelect",
                                                    nCases = c(2000,2500,8000,13000,20000),
                                                    tuning = 0,
                                                    nReps = 500,
                                                    nCores = detectCores()-2
)

plot(simResReplicationMid) #now all are good
plot(simResReplicationMid,yvar = c("ExpectedInfluence","closeness","betweenness","strength")) #all good again

simResOld <- netSimulator(recnetsAge$network$Old,
                             dataGenerator = ggmGenerator(ordinal = TRUE, nLevels = 5),
                             default = "ggmModSelect",
                             nCases = c(2000,2500,8000,13000,20000),
                             tuning = 0,
                             nReps = 500,
                             nCores = detectCores()-2
)

#simRes2
plot(simResOld) #now all are good
plot(simResOld,yvar = c("ExpectedInfluence","closeness","betweenness","strength")) #all good again

simResReplicationOld <- replicationSimulator(recnetsAge$network$Old,
                                                dataGenerator = ggmGenerator(ordinal = TRUE, nLevels = 5),
                                                default = "ggmModSelect",
                                                nCases = c(2000,2500,8000,13000,20000),
                                                tuning = 0,
                                                nReps = 500,
                                                nCores = detectCores()-2
)

plot(simResReplicationOld) #now all are good
plot(simResReplicationOld,yvar = c("ExpectedInfluence","closeness","betweenness","strength")) #all good again

#all countries in a single plot
SimRepYoung_mlt <- select(simResYoung, nCases, sensitivity:correlation) %>%
  melt(id.vars = "nCases") %>%
  mutate(network = "Young")

SimRepMid_mlt <- select(simResMid, nCases, sensitivity:correlation) %>%
  melt(id.vars = "nCases") %>%
  mutate(network = "Mid")

SimRepOld_mlt <- select(simResOld, nCases, sensitivity:correlation) %>%
  melt(id.vars = "nCases") %>%
  mutate(network = "Old")

SimRepCountry_mlt <- rbind(SimRepYoung_mlt, SimRepMid_mlt, SimRepOld_mlt)
SimRepCountry_mlt$network <- factor(SimRepCountry_mlt$network, levels = c("Young", "Mid", "Old"))

# colorblind palette
cbbPaletteAge <- c("#FFC2D1", "#FFB3C6", "#FF8FAB")


repRepSimCountry_plt <- ggplot(SimRepCountry_mlt, aes(x = factor(nCases), y = value, fill = network)) +
  geom_boxplot() +
  facet_wrap(~variable) +
  xlab("sample size") + 
  ylab("") +
  scale_colour_manual(values = cbbPaletteAge) +
  scale_fill_manual(values = cbbPaletteAge) +
  theme_bw() + 
  theme(legend.text = element_text(size = 15), 
        legend.title = element_text(size = 15),
        strip.text.x = element_text(size = 15),
        axis.text.x = element_text(size = 11, angle = 90),
        axis.title.x =  element_text(size = 15),
        legend.key.size = unit(1, "in"),
        axis.text.y = element_text(size = 9)
  )


repRepSimCountry_plt

#now with centrality indices
SimRepYoungCentrality_mlt <- select(simResYoung, nCases, strength:ExpectedInfluence) %>%
  melt(id.vars = "nCases") %>%
  mutate(network = "Young")

SimRepMidCentrality_mlt <- select(simResMid, nCases, strength:ExpectedInfluence) %>%
  melt(id.vars = "nCases") %>%
  mutate(network = "Mid")

SimRepOldCentrality_mlt <- select(simResOld, nCases, strength:ExpectedInfluence) %>%
  melt(id.vars = "nCases") %>%
  mutate(network = "Old")

SimRepCountryCentrality_mlt <- rbind(SimRepYoungCentrality_mlt, SimRepMidCentrality_mlt, SimRepOldCentrality_mlt)
SimRepCountryCentrality_mlt$network <- factor(SimRepCountryCentrality_mlt$network, levels = c("Young", "Mid", "Old"))

# colorblind palette
cbbPaletteAge <- c("#FFC2D1", "#FFB3C6", "#FF8FAB")


repRepSimCountryCentrality_plt <- ggplot(SimRepCountryCentrality_mlt, aes(x = factor(nCases), y = value, fill = network)) +
  geom_boxplot() +
  facet_wrap(~variable) +
  xlab("sample size") + 
  ylab("") +
  scale_colour_manual(values = cbbPaletteAge) +
  scale_fill_manual(values = cbbPaletteAge) +
  theme_bw() + 
  theme(legend.text = element_text(size = 15), 
        legend.title = element_text(size = 15),
        strip.text.x = element_text(size = 15),
        axis.text.x = element_text(size = 11, angle = 90),
        axis.title.x =  element_text(size = 15),
        legend.key.size = unit(1, "in"),
        axis.text.y = element_text(size = 9)
  )


repRepSimCountryCentrality_plt

#now with replication indices
SimRepYoung_mlt <- select(simResReplicationYoung, nCases, correlationNonZero:replicatedZeroes) %>%
  melt(id.vars = "nCases") %>%
  mutate(network = "Young")

SimRepMid_mlt <- select(simResReplicationMid, nCases, correlationNonZero:replicatedZeroes) %>%
  melt(id.vars = "nCases") %>%
  mutate(network = "Mid")

SimRepOld_mlt <- select(simResReplicationOld, nCases, correlationNonZero:replicatedZeroes) %>%
  melt(id.vars = "nCases") %>%
  mutate(network = "Old")

SimRepCountry_mlt <- rbind(SimRepYoung_mlt, SimRepMid_mlt, SimRepOld_mlt)
SimRepCountry_mlt$network <- factor(SimRepCountry_mlt$network, levels = c("Young", "Mid", "Old"))

# colorblind palette
cbbPaletteAge <- c("#FFC2D1", "#FFB3C6", "#FF8FAB")


repRepSimCountry_plt <- ggplot(SimRepCountry_mlt, aes(x = factor(nCases), y = value, fill = network)) +
  geom_boxplot() +
  facet_wrap(~variable) +
  xlab("sample size") + 
  ylab("") +
  scale_colour_manual(values = cbbPaletteAge) +
  scale_fill_manual(values = cbbPaletteAge) +
  theme_bw() + 
  theme(legend.text = element_text(size = 15), 
        legend.title = element_text(size = 15),
        strip.text.x = element_text(size = 15),
        axis.text.x = element_text(size = 11, angle = 90),
        axis.title.x =  element_text(size = 15),
        legend.key.size = unit(1, "in"),
        axis.text.y = element_text(size = 9)
  )


repRepSimCountry_plt

#now with centrality indices
SimRepYoungCentrality_mlt <- select(simRepResYoung, nCases, strength:betweenness) %>%
  melt(id.vars = "nCases") %>%
  mutate(network = "trait")

SimRepMidCentrality_mlt <- select(simRepResMid, nCases, strength:betweenness) %>%
  melt(id.vars = "nCases") %>%
  mutate(network = "facet")

SimRepOldCentrality_mlt <- select(simRepResOld, nCases, strength:betweenness) %>%
  melt(id.vars = "nCases") %>%
  mutate(network = "item")

SimRepCountryCentrality_mlt <- rbind(SimRepYoungCentrality_mlt, SimRepMidCentrality_mlt, SimRepOldCentrality_mlt)
SimRepCountryCentrality_mlt$network <- factor(SimRepCountryCentrality_mlt$network, levels = c("Young", "Mid", "Old"))

# colorblind palette
cbbPaletteAge <- c("#FFC2D1", "#FFB3C6", "#FF8FAB")


repRepSimCountryCentrality_plt <- ggplot(SimRepCountryCentrality_mlt, aes(x = factor(nCases), y = value, fill = network)) +
  geom_boxplot() +
  facet_wrap(~variable) +
  xlab("sample size") + 
  ylab("") +
  scale_colour_manual(values = cbbPaletteAge) +
  scale_fill_manual(values = cbbPaletteAge) +
  theme_bw() + 
  theme(legend.text = element_text(size = 15), 
        legend.title = element_text(size = 15),
        strip.text.x = element_text(size = 15),
        axis.text.x = element_text(size = 11, angle = 90),
        axis.title.x =  element_text(size = 15),
        legend.key.size = unit(1, "in"),
        axis.text.y = element_text(size = 9)
  )


repRepSimCountryCentrality_plt



##################################

# EGA for each network

recnets$network$males
recnets$network$females

recnetsCountry$network$Iran
recnetsCountry$network$Bangladesh
recnetsCountry$network$Norway

recnetsAge$network$Young
recnetsAge$network$Mid
recnetsAge$network$Old

set.seed(46581)

#gender

for(i in 3:20) {
  sgcmales <- EGA(recnets$network$males,model="glasso",n=10221,steps=i,plot.EGA=FALSE)
  print(sgcmales$dim.variables$dimension)
  print(table(sgcmales$dim.variables$dimension))
}

for(i in 3:20) {
  sgcfemales <- EGA(recnets$network$females,model="glasso",n=11746,steps=i,plot.EGA=FALSE)
  print(sgcfemales$dim.variables$dimension)
  print(table(sgcfemales$dim.variables$dimension))
}

#country

for(i in 3:20) {
  sgcIran <- EGA(recnetsCountry$network$Iran,model="glasso",n=10843,steps=i,plot.EGA=FALSE)
  print(sgcIran$dim.variables$dimension)
  print(table(sgcIran$dim.variables$dimension))
}

for(i in 3:20) {
  sgcBangladesh <- EGA(recnetsCountry$network$Bangladesh,model="glasso",n=10058,steps=i,plot.EGA=FALSE)
  print(sgcBangladesh$dim.variables$dimension)
  print(table(sgcBangladesh$dim.variables$dimension))
}

for(i in 3:20) {
  sgcNorway <- EGA(recnetsCountry$network$Norway,model="glasso",n=3680,steps=i,plot.EGA=FALSE)
  print(sgcNorway$dim.variables$dimension)
  print(table(sgcNorway$dim.variables$dimension))
}

#age

for(i in 3:20) {
  sgcyoung <- EGA(recnetsAge$network$Young,model="glasso",n=13655,steps=i,plot.EGA=FALSE)
  print(sgcyoung$dim.variables$dimension)
  print(table(sgcyoung$dim.variables$dimension))
}

for(i in 3:20) {
  sgcmid <- EGA(recnetsAge$network$Mid,model="glasso",n=8113,steps=i,plot.EGA=FALSE)
  print(sgcmid$dim.variables$dimension)
  print(table(sgcmid$dim.variables$dimension))
}

for(i in 3:20) {
  sgcold <- EGA(recnetsAge$network$Old,model="glasso",n=2412,steps=i,plot.EGA=FALSE)
  print(sgcold$dim.variables$dimension)
  print(table(sgcold$dim.variables$dimension))
}


#all samples in all steps of walktrap showed 2 clusters

## BOOTSTRAP EGA - errors due to not positive-definite covariance matrix

bootegamales <- bootEGA(data=dataMales,n=500,model="glasso",type="resampling",algorithm="walktrap",typicalStructure=TRUE,plot.typicalStructure=TRUE,ncores=detectCores()-2,iter=1000)
bootegafemales <- bootEGA(data=dataMales,n=500,model="glasso",type="resampling",algorithm="walktrap",typicalStructure=TRUE,plot.typicalStructure=TRUE,ncores=detectCores()-2,iter=1000)

bootegairan <- bootEGA(data=dataIran,n=500,model="glasso",type="resampling",algorithm="walktrap",typicalStructure=TRUE,plot.typicalStructure=TRUE,ncores=detectCores()-2,iter=1000)
bootegabangladesh <- bootEGA(data=dataBangladesh,n=500,model="glasso",type="resampling",algorithm="walktrap",typicalStructure=TRUE,plot.typicalStructure=TRUE,ncores=detectCores()-2,iter=1000)
booteganorway <- bootEGA(data=dataNorway,n=500,model="glasso",type="resampling",algorithm="walktrap",typicalStructure=TRUE,plot.typicalStructure=TRUE,ncores=detectCores()-2,iter=1000)

bootegayoung <- bootEGA(data=dataYoung,n=500,model="glasso",type="resampling",algorithm="walktrap",typicalStructure=TRUE,plot.typicalStructure=TRUE,ncores=detectCores()-2,iter=1000)
bootegamid <- bootEGA(data=dataMid,n=500,model="glasso",type="resampling",algorithm="walktrap",typicalStructure=TRUE,plot.typicalStructure=TRUE,ncores=detectCores()-2,iter=1000)
bootegaold <- bootEGA(data=dataOld,n=500,model="glasso",type="resampling",algorithm="walktrap",typicalStructure=TRUE,plot.typicalStructure=TRUE,ncores=detectCores()-2,iter=1000)


cbind(bootegamales$summary.table,bootegamales$frequency)
cbind(bootegafemales$summary.table,bootegafemales$frequency)

cbind(bootegairan$summary.table,bootegairan$frequency)
cbind(bootegabangladesh$summary.table,bootegabangladesh$frequency)
cbind(booteganorway$summary.table,booteganorway$frequency)

cbind(bootegayoung$summary.table,bootegayoung$frequency)
cbind(bootegamid$summary.table,bootegamid$frequency)
cbind(bootegaold$summary.table,bootegaold$frequency)



#graphs
plot(bootegamales)
bootegamales$typicalGraph

#extra indices for bootstrap
#itemStability(bootegacovid,egacovid3$wc,item.freq=0.10,plot.item.rep=TRUE)

dimensionStability(bootegamales,sgcmales$wc,item.stability=TRUE)
dimensionStability(bootegamales,sgcmales$wc,item.stability=FALSE) 

dimensionStability(bootegafemales,sgcfemales$wc,item.stability=TRUE)
dimensionStability(bootegafemales,sgcfemales$wc,item.stability=FALSE) 


dimensionStability(bootegairan,sgcIran$wc,item.stability=TRUE)
dimensionStability(bootegairan,sgcIran$wc,item.stability=FALSE) 

dimensionStability(bootegabangladesh,sgcBangladesh$wc,item.stability=TRUE)
dimensionStability(bootegabangladesh,sgcBangladesh$wc,item.stability=FALSE) 

dimensionStability(booteganorway,sgcNorway$wc,item.stability=TRUE)
dimensionStability(booteganorway,sgcNorway$wc,item.stability=FALSE) 


dimensionStability(bootegayoung,sgcyoung$wc,item.stability=TRUE)
dimensionStability(bootegayoung,sgcyoung$wc,item.stability=FALSE) 

dimensionStability(bootegamid,sgcmid$wc,item.stability=TRUE)
dimensionStability(bootegamid,sgcmid$wc,item.stability=FALSE) 

dimensionStability(bootegaold,sgcold$wc,item.stability=TRUE)
dimensionStability(bootegaold,sgcold$wc,item.stability=FALSE) 

####################


# network and centrality
LayoutGender <- qgraph::averageLayout(resultsMales, resultsFemales)
layout(t(1:2))
plot(resultsMales, layout = LayoutGender, title = "Males",pie = predmales$error$R2)
plot(resultsFemales, layout = LayoutGender, title = "Females",pie = predfemales$error$R2)

centrality(list(Males = resultsMales,Females = resultsFemales))

centralityPlot(
  list(Males = resultsMales,Females = resultsFemales), 
  include = c("Strength","ExpectedInfluence","Closeness","Betweenness")
)

LayoutSample <- qgraph::averageLayout(resultsIran, resultsBangladesh)
layout(t(1:2))
plot(resultsMales, layout = LayoutSample, title = "Iran",pie = predmales$error$R2)
plot(resultsFemales, layout = LayoutSample, title = "Bangladesh",pie = predfemales$error$R2)

centrality(list(Iran = resultsIran,Bangladesh = resultsBangladesh))

centralityPlot(
  list(Iran = resultsIran,Bangladesh = resultsBangladesh), 
  include = c("Strength","ExpectedInfluence","Closeness","Betweenness")
)

#bootstrap edges and centrality for both

boot1Males <- bootnet(resultsMales, nCores = 14, #introduce as many cores as detectCores() detects - 2
                 nBoots = 1000, type ='nonparametric', statistics = c("bridgeExpectedInfluence", "bridgeStrength", "bridgeCloseness","bridgeBetweenness"),
                 weighted=TRUE,signed=TRUE,memorysaver=TRUE)
plot(boot1Males, statistics = "all",order = "sample")
plot(boot1Males, statistics = "all",order = "sample",plot="line")
plot(boot1Males,"edge", plot = "interval", order = "sample") #confidence intervals instead of shades
plot(boot1Males,c("bridgeExpectedInfluence", "bridgeStrength", "bridgeCloseness","bridgeBetweenness"), plot = "area", order = "sample") #interpret CIs with care due to being unstable
plot(boot1Males,c("bridgeExpectedInfluence", "bridgeStrength", "bridgeCloseness","bridgeBetweenness"), plot = "interval", order = "sample") #interpret CIs with care due to being unstable
plot(boot1Males,c("bridgeExpectedInfluence", "bridgeStrength", "bridgeCloseness","bridgeBetweenness"), plot = "line", order = "sample") 


plot(boot1Males, "edge", plot = "difference",
     onlyNonZero = TRUE, differenceShowValue=FALSE, 
     differenceEdgeColor=TRUE, order = "sample") #significant differences between each edge (black = sig; grey = ns)
plot(boot1Males, c("bridgeExpectedInfluence", "bridgeStrength", "bridgeCloseness","bridgeBetweenness"), plot = "difference") 


boot2Males <- bootnet(resultsMales, nCores = 14,nBoots = 1000, type ='case',statistics = c("bridgeExpectedInfluence", "bridgeStrength", "bridgeCloseness","bridgeBetweenness"))
plot(boot2Males,statistics = "edge")
plot(boot2Males,statistics = c("bridgeExpectedInfluence", "bridgeStrength", "bridgeCloseness","bridgeBetweenness"))

# Compute CS-coefficients: Cautious interpretation rules = above .25 minimum, above .50 ideal
corStability(boot2Males,cor=0.7,statistics="edge",verbose=TRUE) #changing the "cor" argument does not change the output



boot1Females <- bootnet(resultsFemales, nCores = 14, #introduce as many cores as detectCores() detects - 2
                      nBoots = 1000, type ='nonparametric', statistics = c("bridgeExpectedInfluence", "bridgeStrength", "bridgeCloseness","bridgeBetweenness"),
                      weighted=TRUE,signed=TRUE,memorysaver=TRUE)
plot(boot1Females, statistics = "all",order = "sample")
plot(boot1Females, statistics = "all",order = "sample",plot="line")
plot(boot1Females,"edge", plot = "interval", order = "sample") #confidence intervals instead of shades
plot(boot1Females,c("bridgeExpectedInfluence", "bridgeStrength", "bridgeCloseness","bridgeBetweenness"), plot = "area", order = "sample") #interpret CIs with care due to being unstable
plot(boot1Females,c("bridgeExpectedInfluence", "bridgeStrength", "bridgeCloseness","bridgeBetweenness"), plot = "interval", order = "sample") #interpret CIs with care due to being unstable
plot(boot1Females,c("bridgeExpectedInfluence", "bridgeStrength", "bridgeCloseness","bridgeBetweenness"), plot = "line", order = "sample") 


plot(boot1Females, "edge", plot = "difference",
     onlyNonZero = TRUE, differenceShowValue=FALSE, 
     differenceEdgeColor=TRUE, order = "sample") #significant differences between each edge (black = sig; grey = ns)
plot(boot1Females, c("strength","expectedInfluence","closeness","betweenness"), plot = "difference") 


boot2Females <- bootnet(resultsFemales, nCores = 14,nBoots = 1000, type ='case',statistics = c("bridgeExpectedInfluence", "bridgeStrength", "bridgeCloseness","bridgeBetweenness"))
plot(boot2Females,statistics = "edge")
plot(boot2Females,statistics = c("bridgeExpectedInfluence", "bridgeStrength", "bridgeCloseness","bridgeBetweenness"))

# Compute CS-coefficients: Cautious interpretation rules = above .25 minimum, above .50 ideal
corStability(boot2Females,cor=0.7,statistics="edge",verbose=TRUE) #changing the "cor" argument does not change the output



boot1Iran <- bootnet(resultsIran, nCores = 14, #introduce as many cores as detectCores() detects - 2
                      nBoots = 1000, type ='nonparametric', statistics = c("bridgeExpectedInfluence", "bridgeStrength", "bridgeCloseness","bridgeBetweenness"),
                      weighted=TRUE,signed=TRUE,memorysaver=TRUE)
plot(boot1Iran, statistics = "all",order = "sample")
plot(boot1Iran, statistics = "all",order = "sample",plot="line")
plot(boot1Iran,"edge", plot = "interval", order = "sample") #confidence intervals instead of shades
plot(boot1Iran,c("bridgeExpectedInfluence", "bridgeStrength", "bridgeCloseness","bridgeBetweenness"), plot = "area", order = "sample") #interpret CIs with care due to being unstable
plot(boot1Iran,c("bridgeExpectedInfluence", "bridgeStrength", "bridgeCloseness","bridgeBetweenness"), plot = "interval", order = "sample") #interpret CIs with care due to being unstable
plot(boot1Iran,c("bridgeExpectedInfluence", "bridgeStrength", "bridgeCloseness","bridgeBetweenness"), plot = "line", order = "sample") 


plot(boot1Iran, "edge", plot = "difference",
     onlyNonZero = TRUE, differenceShowValue=FALSE, 
     differenceEdgeColor=TRUE, order = "sample") #significant differences between each edge (black = sig; grey = ns)
plot(boot1Iran, c("bridgeExpectedInfluence", "bridgeStrength", "bridgeCloseness","bridgeBetweenness"), plot = "difference") 


boot2Iran <- bootnet(resultsIran, nCores = 14,nBoots = 1000, type ='case',statistics = c("bridgeExpectedInfluence", "bridgeStrength", "bridgeCloseness","bridgeBetweenness"))
plot(boot2Iran,statistics = "edge")
plot(boot2Iran,statistics = c("bridgeExpectedInfluence", "bridgeStrength", "bridgeCloseness","bridgeBetweenness"))

# Compute CS-coefficients: Cautious interpretation rules = above .25 minimum, above .50 ideal
corStability(boot2Iran,cor=0.7,statistics="edge",verbose=TRUE) #changing the "cor" argument does not change the output



boot1Bangladesh <- bootnet(resultsBangladesh, nCores = 14, #introduce as many cores as detectCores() detects - 2
                      nBoots = 1000, type ='nonparametric', statistics = c("bridgeExpectedInfluence", "bridgeStrength", "bridgeCloseness","bridgeBetweenness"),
                      weighted=TRUE,signed=TRUE,memorysaver=TRUE)
plot(boot1Bangladesh, statistics = "all",order = "sample")
plot(boot1Bangladesh, statistics = "all",order = "sample",plot="line")
plot(boot1Bangladesh,"edge", plot = "interval", order = "sample") #confidence intervals instead of shades
plot(boot1Bangladesh,c("bridgeExpectedInfluence", "bridgeStrength", "bridgeCloseness","bridgeBetweenness"), plot = "area", order = "sample") #interpret CIs with care due to being unstable
plot(boot1Bangladesh,c("bridgeExpectedInfluence", "bridgeStrength", "bridgeCloseness","bridgeBetweenness"), plot = "interval", order = "sample") #interpret CIs with care due to being unstable
plot(boot1Bangladesh,c("bridgeExpectedInfluence", "bridgeStrength", "bridgeCloseness","bridgeBetweenness"), plot = "line", order = "sample") 


plot(boot1Bangladesh, "edge", plot = "difference",
     onlyNonZero = TRUE, differenceShowValue=FALSE, 
     differenceEdgeColor=TRUE, order = "sample") #significant differences between each edge (black = sig; grey = ns)
plot(boot1Bangladesh, c("strength","expectedInfluence","closeness","betweenness"), plot = "difference") 


boot2Bangladesh <- bootnet(resultsBangladesh, nCores = 14,nBoots = 1000, type ='case',statistics = c("edge","strength","expectedInfluence", "betweenness","closeness"))
plot(boot2Bangladesh,statistics = "edge")
plot(boot2Bangladesh,statistics = c("bridgeExpectedInfluence", "bridgeStrength", "bridgeCloseness","bridgeBetweenness"))

# Compute CS-coefficients: Cautious interpretation rules = above .25 minimum, above .50 ideal
corStability(boot2Bangladesh,cor=0.7,statistics="edge",verbose=TRUE) #changing the "cor" argument does not change the output


#corStability analyses for both




# network and centrality

#bootstrap edges and centrality for both

#corStability analyses for both


####################






################# LATENT CLASS ANALYSIS #####################
